// Copyright 2015, VIXL authors
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//   * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//   * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//   * Neither the name of ARM Limited nor the names of its contributors may be
//     used to endorse or promote products derived from this software without
//     specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


// ---------------------------------------------------------------------
// This file is auto generated using tools/generate_simulator_traces.py.
//
// PLEASE DO NOT EDIT.
// ---------------------------------------------------------------------

#ifndef VIXL_ASSEMBLER_COND_RD_RN_OPERAND_RM_SHIFT_AMOUNT_1TO31_SBC_T32_H_
#define VIXL_ASSEMBLER_COND_RD_RN_OPERAND_RM_SHIFT_AMOUNT_1TO31_SBC_T32_H_

const byte kInstruction_sbc_al_r12_r4_r7_LSL_7[] = {
  0x64, 0xeb, 0xc7, 0x1c // sbc al r12 r4 r7 LSL 7
};
const byte kInstruction_sbc_al_r7_r8_r10_ROR_21[] = {
  0x68, 0xeb, 0x7a, 0x57 // sbc al r7 r8 r10 ROR 21
};
const byte kInstruction_sbc_al_r5_r5_r3_ROR_12[] = {
  0x65, 0xeb, 0x33, 0x35 // sbc al r5 r5 r3 ROR 12
};
const byte kInstruction_sbc_al_r14_r13_r10_LSL_22[] = {
  0x6d, 0xeb, 0x8a, 0x5e // sbc al r14 r13 r10 LSL 22
};
const byte kInstruction_sbc_al_r9_r10_r11_ROR_2[] = {
  0x6a, 0xeb, 0xbb, 0x09 // sbc al r9 r10 r11 ROR 2
};
const byte kInstruction_sbc_al_r14_r11_r5_LSL_15[] = {
  0x6b, 0xeb, 0xc5, 0x3e // sbc al r14 r11 r5 LSL 15
};
const byte kInstruction_sbc_al_r2_r2_r7_LSL_28[] = {
  0x62, 0xeb, 0x07, 0x72 // sbc al r2 r2 r7 LSL 28
};
const byte kInstruction_sbc_al_r2_r11_r1_ROR_9[] = {
  0x6b, 0xeb, 0x71, 0x22 // sbc al r2 r11 r1 ROR 9
};
const byte kInstruction_sbc_al_r11_r2_r8_LSL_4[] = {
  0x62, 0xeb, 0x08, 0x1b // sbc al r11 r2 r8 LSL 4
};
const byte kInstruction_sbc_al_r6_r13_r3_ROR_1[] = {
  0x6d, 0xeb, 0x73, 0x06 // sbc al r6 r13 r3 ROR 1
};
const byte kInstruction_sbc_al_r13_r2_r7_LSL_11[] = {
  0x62, 0xeb, 0xc7, 0x2d // sbc al r13 r2 r7 LSL 11
};
const byte kInstruction_sbc_al_r9_r9_r1_LSL_29[] = {
  0x69, 0xeb, 0x41, 0x79 // sbc al r9 r9 r1 LSL 29
};
const byte kInstruction_sbc_al_r2_r12_r1_LSL_15[] = {
  0x6c, 0xeb, 0xc1, 0x32 // sbc al r2 r12 r1 LSL 15
};
const byte kInstruction_sbc_al_r0_r2_r11_LSL_10[] = {
  0x62, 0xeb, 0x8b, 0x20 // sbc al r0 r2 r11 LSL 10
};
const byte kInstruction_sbc_al_r11_r12_r8_LSL_13[] = {
  0x6c, 0xeb, 0x48, 0x3b // sbc al r11 r12 r8 LSL 13
};
const byte kInstruction_sbc_al_r3_r1_r6_ROR_3[] = {
  0x61, 0xeb, 0xf6, 0x03 // sbc al r3 r1 r6 ROR 3
};
const byte kInstruction_sbc_al_r5_r9_r11_LSL_16[] = {
  0x69, 0xeb, 0x0b, 0x45 // sbc al r5 r9 r11 LSL 16
};
const byte kInstruction_sbc_al_r2_r0_r6_ROR_3[] = {
  0x60, 0xeb, 0xf6, 0x02 // sbc al r2 r0 r6 ROR 3
};
const byte kInstruction_sbc_al_r7_r10_r10_ROR_19[] = {
  0x6a, 0xeb, 0xfa, 0x47 // sbc al r7 r10 r10 ROR 19
};
const byte kInstruction_sbc_al_r14_r12_r11_LSL_27[] = {
  0x6c, 0xeb, 0xcb, 0x6e // sbc al r14 r12 r11 LSL 27
};
const byte kInstruction_sbc_al_r2_r13_r1_LSL_3[] = {
  0x6d, 0xeb, 0xc1, 0x02 // sbc al r2 r13 r1 LSL 3
};
const byte kInstruction_sbc_al_r5_r3_r2_LSL_11[] = {
  0x63, 0xeb, 0xc2, 0x25 // sbc al r5 r3 r2 LSL 11
};
const byte kInstruction_sbc_al_r10_r3_r6_ROR_1[] = {
  0x63, 0xeb, 0x76, 0x0a // sbc al r10 r3 r6 ROR 1
};
const byte kInstruction_sbc_al_r6_r14_r2_ROR_13[] = {
  0x6e, 0xeb, 0x72, 0x36 // sbc al r6 r14 r2 ROR 13
};
const byte kInstruction_sbc_al_r9_r8_r6_ROR_13[] = {
  0x68, 0xeb, 0x76, 0x39 // sbc al r9 r8 r6 ROR 13
};
const byte kInstruction_sbc_al_r12_r5_r8_LSL_22[] = {
  0x65, 0xeb, 0x88, 0x5c // sbc al r12 r5 r8 LSL 22
};
const byte kInstruction_sbc_al_r11_r8_r11_LSL_3[] = {
  0x68, 0xeb, 0xcb, 0x0b // sbc al r11 r8 r11 LSL 3
};
const byte kInstruction_sbc_al_r0_r9_r4_LSL_24[] = {
  0x69, 0xeb, 0x04, 0x60 // sbc al r0 r9 r4 LSL 24
};
const byte kInstruction_sbc_al_r2_r2_r7_ROR_30[] = {
  0x62, 0xeb, 0xb7, 0x72 // sbc al r2 r2 r7 ROR 30
};
const byte kInstruction_sbc_al_r9_r3_r10_LSL_27[] = {
  0x63, 0xeb, 0xca, 0x69 // sbc al r9 r3 r10 LSL 27
};
const byte kInstruction_sbc_al_r10_r4_r11_LSL_23[] = {
  0x64, 0xeb, 0xcb, 0x5a // sbc al r10 r4 r11 LSL 23
};
const byte kInstruction_sbc_al_r12_r5_r11_ROR_8[] = {
  0x65, 0xeb, 0x3b, 0x2c // sbc al r12 r5 r11 ROR 8
};
const byte kInstruction_sbc_al_r6_r6_r6_ROR_4[] = {
  0x66, 0xeb, 0x36, 0x16 // sbc al r6 r6 r6 ROR 4
};
const byte kInstruction_sbc_al_r5_r5_r10_ROR_29[] = {
  0x65, 0xeb, 0x7a, 0x75 // sbc al r5 r5 r10 ROR 29
};
const byte kInstruction_sbc_al_r12_r12_r1_LSL_8[] = {
  0x6c, 0xeb, 0x01, 0x2c // sbc al r12 r12 r1 LSL 8
};
const byte kInstruction_sbc_al_r5_r3_r1_LSL_4[] = {
  0x63, 0xeb, 0x01, 0x15 // sbc al r5 r3 r1 LSL 4
};
const byte kInstruction_sbc_al_r4_r11_r7_LSL_17[] = {
  0x6b, 0xeb, 0x47, 0x44 // sbc al r4 r11 r7 LSL 17
};
const byte kInstruction_sbc_al_r12_r8_r3_LSL_2[] = {
  0x68, 0xeb, 0x83, 0x0c // sbc al r12 r8 r3 LSL 2
};
const byte kInstruction_sbc_al_r2_r11_r3_LSL_13[] = {
  0x6b, 0xeb, 0x43, 0x32 // sbc al r2 r11 r3 LSL 13
};
const byte kInstruction_sbc_al_r11_r11_r4_ROR_19[] = {
  0x6b, 0xeb, 0xf4, 0x4b // sbc al r11 r11 r4 ROR 19
};
const byte kInstruction_sbc_al_r5_r1_r3_LSL_4[] = {
  0x61, 0xeb, 0x03, 0x15 // sbc al r5 r1 r3 LSL 4
};
const byte kInstruction_sbc_al_r2_r5_r7_ROR_20[] = {
  0x65, 0xeb, 0x37, 0x52 // sbc al r2 r5 r7 ROR 20
};
const byte kInstruction_sbc_al_r8_r8_r1_LSL_24[] = {
  0x68, 0xeb, 0x01, 0x68 // sbc al r8 r8 r1 LSL 24
};
const byte kInstruction_sbc_al_r7_r1_r0_LSL_11[] = {
  0x61, 0xeb, 0xc0, 0x27 // sbc al r7 r1 r0 LSL 11
};
const byte kInstruction_sbc_al_r10_r5_r0_LSL_17[] = {
  0x65, 0xeb, 0x40, 0x4a // sbc al r10 r5 r0 LSL 17
};
const byte kInstruction_sbc_al_r14_r13_r13_ROR_18[] = {
  0x6d, 0xeb, 0xbd, 0x4e // sbc al r14 r13 r13 ROR 18
};
const byte kInstruction_sbc_al_r8_r3_r11_LSL_4[] = {
  0x63, 0xeb, 0x0b, 0x18 // sbc al r8 r3 r11 LSL 4
};
const byte kInstruction_sbc_al_r1_r11_r10_LSL_2[] = {
  0x6b, 0xeb, 0x8a, 0x01 // sbc al r1 r11 r10 LSL 2
};
const byte kInstruction_sbc_al_r0_r2_r11_LSL_25[] = {
  0x62, 0xeb, 0x4b, 0x60 // sbc al r0 r2 r11 LSL 25
};
const byte kInstruction_sbc_al_r0_r1_r12_LSL_7[] = {
  0x61, 0xeb, 0xcc, 0x10 // sbc al r0 r1 r12 LSL 7
};
const byte kInstruction_sbc_al_r5_r0_r8_LSL_19[] = {
  0x60, 0xeb, 0xc8, 0x45 // sbc al r5 r0 r8 LSL 19
};
const byte kInstruction_sbc_al_r1_r5_r8_ROR_16[] = {
  0x65, 0xeb, 0x38, 0x41 // sbc al r1 r5 r8 ROR 16
};
const byte kInstruction_sbc_al_r5_r11_r0_LSL_7[] = {
  0x6b, 0xeb, 0xc0, 0x15 // sbc al r5 r11 r0 LSL 7
};
const byte kInstruction_sbc_al_r4_r5_r9_LSL_28[] = {
  0x65, 0xeb, 0x09, 0x74 // sbc al r4 r5 r9 LSL 28
};
const byte kInstruction_sbc_al_r2_r6_r0_ROR_5[] = {
  0x66, 0xeb, 0x70, 0x12 // sbc al r2 r6 r0 ROR 5
};
const byte kInstruction_sbc_al_r8_r13_r4_ROR_19[] = {
  0x6d, 0xeb, 0xf4, 0x48 // sbc al r8 r13 r4 ROR 19
};
const byte kInstruction_sbc_al_r10_r11_r4_LSL_27[] = {
  0x6b, 0xeb, 0xc4, 0x6a // sbc al r10 r11 r4 LSL 27
};
const byte kInstruction_sbc_al_r2_r8_r10_ROR_12[] = {
  0x68, 0xeb, 0x3a, 0x32 // sbc al r2 r8 r10 ROR 12
};
const byte kInstruction_sbc_al_r8_r11_r8_ROR_30[] = {
  0x6b, 0xeb, 0xb8, 0x78 // sbc al r8 r11 r8 ROR 30
};
const byte kInstruction_sbc_al_r7_r12_r14_LSL_21[] = {
  0x6c, 0xeb, 0x4e, 0x57 // sbc al r7 r12 r14 LSL 21
};
const byte kInstruction_sbc_al_r1_r7_r14_LSL_18[] = {
  0x67, 0xeb, 0x8e, 0x41 // sbc al r1 r7 r14 LSL 18
};
const byte kInstruction_sbc_al_r1_r2_r11_ROR_26[] = {
  0x62, 0xeb, 0xbb, 0x61 // sbc al r1 r2 r11 ROR 26
};
const byte kInstruction_sbc_al_r12_r10_r0_ROR_10[] = {
  0x6a, 0xeb, 0xb0, 0x2c // sbc al r12 r10 r0 ROR 10
};
const byte kInstruction_sbc_al_r4_r4_r10_ROR_22[] = {
  0x64, 0xeb, 0xba, 0x54 // sbc al r4 r4 r10 ROR 22
};
const byte kInstruction_sbc_al_r10_r10_r11_LSL_25[] = {
  0x6a, 0xeb, 0x4b, 0x6a // sbc al r10 r10 r11 LSL 25
};
const byte kInstruction_sbc_al_r5_r11_r12_LSL_20[] = {
  0x6b, 0xeb, 0x0c, 0x55 // sbc al r5 r11 r12 LSL 20
};
const byte kInstruction_sbc_al_r6_r14_r7_LSL_26[] = {
  0x6e, 0xeb, 0x87, 0x66 // sbc al r6 r14 r7 LSL 26
};
const byte kInstruction_sbc_al_r10_r3_r3_LSL_10[] = {
  0x63, 0xeb, 0x83, 0x2a // sbc al r10 r3 r3 LSL 10
};
const byte kInstruction_sbc_al_r11_r3_r5_LSL_24[] = {
  0x63, 0xeb, 0x05, 0x6b // sbc al r11 r3 r5 LSL 24
};
const byte kInstruction_sbc_al_r9_r5_r10_ROR_23[] = {
  0x65, 0xeb, 0xfa, 0x59 // sbc al r9 r5 r10 ROR 23
};
const byte kInstruction_sbc_al_r4_r6_r5_ROR_28[] = {
  0x66, 0xeb, 0x35, 0x74 // sbc al r4 r6 r5 ROR 28
};
const byte kInstruction_sbc_al_r9_r10_r4_ROR_26[] = {
  0x6a, 0xeb, 0xb4, 0x69 // sbc al r9 r10 r4 ROR 26
};
const byte kInstruction_sbc_al_r9_r0_r9_LSL_2[] = {
  0x60, 0xeb, 0x89, 0x09 // sbc al r9 r0 r9 LSL 2
};
const byte kInstruction_sbc_al_r4_r12_r8_LSL_23[] = {
  0x6c, 0xeb, 0xc8, 0x54 // sbc al r4 r12 r8 LSL 23
};
const byte kInstruction_sbc_al_r7_r9_r11_LSL_18[] = {
  0x69, 0xeb, 0x8b, 0x47 // sbc al r7 r9 r11 LSL 18
};
const byte kInstruction_sbc_al_r5_r2_r3_LSL_19[] = {
  0x62, 0xeb, 0xc3, 0x45 // sbc al r5 r2 r3 LSL 19
};
const byte kInstruction_sbc_al_r5_r5_r1_ROR_10[] = {
  0x65, 0xeb, 0xb1, 0x25 // sbc al r5 r5 r1 ROR 10
};
const byte kInstruction_sbc_al_r3_r0_r7_ROR_27[] = {
  0x60, 0xeb, 0xf7, 0x63 // sbc al r3 r0 r7 ROR 27
};
const byte kInstruction_sbc_al_r8_r12_r8_ROR_14[] = {
  0x6c, 0xeb, 0xb8, 0x38 // sbc al r8 r12 r8 ROR 14
};
const byte kInstruction_sbc_al_r3_r8_r2_LSL_25[] = {
  0x68, 0xeb, 0x42, 0x63 // sbc al r3 r8 r2 LSL 25
};
const byte kInstruction_sbc_al_r8_r5_r8_LSL_24[] = {
  0x65, 0xeb, 0x08, 0x68 // sbc al r8 r5 r8 LSL 24
};
const byte kInstruction_sbc_al_r10_r2_r9_LSL_23[] = {
  0x62, 0xeb, 0xc9, 0x5a // sbc al r10 r2 r9 LSL 23
};
const byte kInstruction_sbc_al_r13_r11_r3_ROR_25[] = {
  0x6b, 0xeb, 0x73, 0x6d // sbc al r13 r11 r3 ROR 25
};
const byte kInstruction_sbc_al_r2_r13_r2_ROR_1[] = {
  0x6d, 0xeb, 0x72, 0x02 // sbc al r2 r13 r2 ROR 1
};
const byte kInstruction_sbc_al_r9_r7_r7_ROR_18[] = {
  0x67, 0xeb, 0xb7, 0x49 // sbc al r9 r7 r7 ROR 18
};
const byte kInstruction_sbc_al_r13_r13_r4_ROR_15[] = {
  0x6d, 0xeb, 0xf4, 0x3d // sbc al r13 r13 r4 ROR 15
};
const byte kInstruction_sbc_al_r1_r2_r0_LSL_1[] = {
  0x62, 0xeb, 0x40, 0x01 // sbc al r1 r2 r0 LSL 1
};
const byte kInstruction_sbc_al_r0_r14_r1_LSL_7[] = {
  0x6e, 0xeb, 0xc1, 0x10 // sbc al r0 r14 r1 LSL 7
};
const byte kInstruction_sbc_al_r2_r2_r3_LSL_18[] = {
  0x62, 0xeb, 0x83, 0x42 // sbc al r2 r2 r3 LSL 18
};
const byte kInstruction_sbc_al_r12_r12_r10_ROR_22[] = {
  0x6c, 0xeb, 0xba, 0x5c // sbc al r12 r12 r10 ROR 22
};
const byte kInstruction_sbc_al_r12_r10_r2_ROR_13[] = {
  0x6a, 0xeb, 0x72, 0x3c // sbc al r12 r10 r2 ROR 13
};
const byte kInstruction_sbc_al_r7_r3_r11_LSL_23[] = {
  0x63, 0xeb, 0xcb, 0x57 // sbc al r7 r3 r11 LSL 23
};
const byte kInstruction_sbc_al_r4_r7_r14_LSL_10[] = {
  0x67, 0xeb, 0x8e, 0x24 // sbc al r4 r7 r14 LSL 10
};
const byte kInstruction_sbc_al_r3_r7_r5_ROR_27[] = {
  0x67, 0xeb, 0xf5, 0x63 // sbc al r3 r7 r5 ROR 27
};
const byte kInstruction_sbc_al_r5_r11_r5_ROR_24[] = {
  0x6b, 0xeb, 0x35, 0x65 // sbc al r5 r11 r5 ROR 24
};
const byte kInstruction_sbc_al_r12_r0_r6_ROR_29[] = {
  0x60, 0xeb, 0x76, 0x7c // sbc al r12 r0 r6 ROR 29
};
const byte kInstruction_sbc_al_r14_r3_r8_LSL_26[] = {
  0x63, 0xeb, 0x88, 0x6e // sbc al r14 r3 r8 LSL 26
};
const byte kInstruction_sbc_al_r12_r10_r3_LSL_10[] = {
  0x6a, 0xeb, 0x83, 0x2c // sbc al r12 r10 r3 LSL 10
};
const byte kInstruction_sbc_al_r3_r8_r6_ROR_16[] = {
  0x68, 0xeb, 0x36, 0x43 // sbc al r3 r8 r6 ROR 16
};
const byte kInstruction_sbc_al_r14_r1_r1_LSL_23[] = {
  0x61, 0xeb, 0xc1, 0x5e // sbc al r14 r1 r1 LSL 23
};
const byte kInstruction_sbc_al_r14_r1_r0_LSL_18[] = {
  0x61, 0xeb, 0x80, 0x4e // sbc al r14 r1 r0 LSL 18
};
const byte kInstruction_sbc_al_r7_r1_r8_LSL_29[] = {
  0x61, 0xeb, 0x48, 0x77 // sbc al r7 r1 r8 LSL 29
};
const byte kInstruction_sbc_al_r8_r12_r1_ROR_22[] = {
  0x6c, 0xeb, 0xb1, 0x58 // sbc al r8 r12 r1 ROR 22
};
const byte kInstruction_sbc_al_r8_r12_r10_ROR_10[] = {
  0x6c, 0xeb, 0xba, 0x28 // sbc al r8 r12 r10 ROR 10
};
const byte kInstruction_sbc_al_r1_r14_r3_ROR_7[] = {
  0x6e, 0xeb, 0xf3, 0x11 // sbc al r1 r14 r3 ROR 7
};
const byte kInstruction_sbc_al_r3_r4_r3_LSL_20[] = {
  0x64, 0xeb, 0x03, 0x53 // sbc al r3 r4 r3 LSL 20
};
const byte kInstruction_sbc_al_r2_r13_r0_LSL_7[] = {
  0x6d, 0xeb, 0xc0, 0x12 // sbc al r2 r13 r0 LSL 7
};
const byte kInstruction_sbc_al_r13_r0_r9_ROR_20[] = {
  0x60, 0xeb, 0x39, 0x5d // sbc al r13 r0 r9 ROR 20
};
const byte kInstruction_sbc_al_r6_r4_r14_ROR_5[] = {
  0x64, 0xeb, 0x7e, 0x16 // sbc al r6 r4 r14 ROR 5
};
const byte kInstruction_sbc_al_r12_r8_r9_ROR_3[] = {
  0x68, 0xeb, 0xf9, 0x0c // sbc al r12 r8 r9 ROR 3
};
const byte kInstruction_sbc_al_r0_r11_r2_LSL_19[] = {
  0x6b, 0xeb, 0xc2, 0x40 // sbc al r0 r11 r2 LSL 19
};
const byte kInstruction_sbc_al_r2_r3_r3_LSL_8[] = {
  0x63, 0xeb, 0x03, 0x22 // sbc al r2 r3 r3 LSL 8
};
const byte kInstruction_sbc_al_r5_r1_r1_ROR_26[] = {
  0x61, 0xeb, 0xb1, 0x65 // sbc al r5 r1 r1 ROR 26
};
const byte kInstruction_sbc_al_r4_r4_r13_ROR_31[] = {
  0x64, 0xeb, 0xfd, 0x74 // sbc al r4 r4 r13 ROR 31
};
const byte kInstruction_sbc_al_r4_r6_r8_ROR_11[] = {
  0x66, 0xeb, 0xf8, 0x24 // sbc al r4 r6 r8 ROR 11
};
const byte kInstruction_sbc_al_r4_r10_r13_LSL_28[] = {
  0x6a, 0xeb, 0x0d, 0x74 // sbc al r4 r10 r13 LSL 28
};
const byte kInstruction_sbc_al_r0_r8_r5_LSL_19[] = {
  0x68, 0xeb, 0xc5, 0x40 // sbc al r0 r8 r5 LSL 19
};
const byte kInstruction_sbc_al_r14_r0_r7_ROR_10[] = {
  0x60, 0xeb, 0xb7, 0x2e // sbc al r14 r0 r7 ROR 10
};
const byte kInstruction_sbc_al_r9_r10_r9_ROR_13[] = {
  0x6a, 0xeb, 0x79, 0x39 // sbc al r9 r10 r9 ROR 13
};
const byte kInstruction_sbc_al_r5_r1_r7_LSL_31[] = {
  0x61, 0xeb, 0xc7, 0x75 // sbc al r5 r1 r7 LSL 31
};
const byte kInstruction_sbc_al_r8_r4_r12_ROR_8[] = {
  0x64, 0xeb, 0x3c, 0x28 // sbc al r8 r4 r12 ROR 8
};
const byte kInstruction_sbc_al_r8_r13_r0_LSL_4[] = {
  0x6d, 0xeb, 0x00, 0x18 // sbc al r8 r13 r0 LSL 4
};
const byte kInstruction_sbc_al_r10_r4_r10_LSL_19[] = {
  0x64, 0xeb, 0xca, 0x4a // sbc al r10 r4 r10 LSL 19
};
const byte kInstruction_sbc_al_r5_r2_r3_LSL_5[] = {
  0x62, 0xeb, 0x43, 0x15 // sbc al r5 r2 r3 LSL 5
};
const byte kInstruction_sbc_al_r1_r1_r2_LSL_17[] = {
  0x61, 0xeb, 0x42, 0x41 // sbc al r1 r1 r2 LSL 17
};
const byte kInstruction_sbc_al_r9_r2_r13_ROR_13[] = {
  0x62, 0xeb, 0x7d, 0x39 // sbc al r9 r2 r13 ROR 13
};
const byte kInstruction_sbc_al_r2_r5_r5_ROR_8[] = {
  0x65, 0xeb, 0x35, 0x22 // sbc al r2 r5 r5 ROR 8
};
const byte kInstruction_sbc_al_r11_r11_r10_ROR_31[] = {
  0x6b, 0xeb, 0xfa, 0x7b // sbc al r11 r11 r10 ROR 31
};
const byte kInstruction_sbc_al_r13_r14_r13_LSL_23[] = {
  0x6e, 0xeb, 0xcd, 0x5d // sbc al r13 r14 r13 LSL 23
};
const byte kInstruction_sbc_al_r9_r0_r3_ROR_6[] = {
  0x60, 0xeb, 0xb3, 0x19 // sbc al r9 r0 r3 ROR 6
};
const byte kInstruction_sbc_al_r10_r10_r11_LSL_9[] = {
  0x6a, 0xeb, 0x4b, 0x2a // sbc al r10 r10 r11 LSL 9
};
const byte kInstruction_sbc_al_r13_r10_r11_ROR_31[] = {
  0x6a, 0xeb, 0xfb, 0x7d // sbc al r13 r10 r11 ROR 31
};
const byte kInstruction_sbc_al_r8_r8_r10_LSL_23[] = {
  0x68, 0xeb, 0xca, 0x58 // sbc al r8 r8 r10 LSL 23
};
const byte kInstruction_sbc_al_r13_r13_r10_ROR_27[] = {
  0x6d, 0xeb, 0xfa, 0x6d // sbc al r13 r13 r10 ROR 27
};
const byte kInstruction_sbc_al_r6_r4_r7_LSL_19[] = {
  0x64, 0xeb, 0xc7, 0x46 // sbc al r6 r4 r7 LSL 19
};
const byte kInstruction_sbc_al_r6_r1_r7_LSL_23[] = {
  0x61, 0xeb, 0xc7, 0x56 // sbc al r6 r1 r7 LSL 23
};
const byte kInstruction_sbc_al_r11_r13_r9_ROR_2[] = {
  0x6d, 0xeb, 0xb9, 0x0b // sbc al r11 r13 r9 ROR 2
};
const byte kInstruction_sbc_al_r14_r13_r8_LSL_11[] = {
  0x6d, 0xeb, 0xc8, 0x2e // sbc al r14 r13 r8 LSL 11
};
const byte kInstruction_sbc_al_r10_r11_r8_ROR_11[] = {
  0x6b, 0xeb, 0xf8, 0x2a // sbc al r10 r11 r8 ROR 11
};
const byte kInstruction_sbc_al_r5_r5_r1_ROR_15[] = {
  0x65, 0xeb, 0xf1, 0x35 // sbc al r5 r5 r1 ROR 15
};
const byte kInstruction_sbc_al_r1_r3_r0_LSL_14[] = {
  0x63, 0xeb, 0x80, 0x31 // sbc al r1 r3 r0 LSL 14
};
const byte kInstruction_sbc_al_r11_r4_r0_ROR_29[] = {
  0x64, 0xeb, 0x70, 0x7b // sbc al r11 r4 r0 ROR 29
};
const byte kInstruction_sbc_al_r6_r11_r10_ROR_25[] = {
  0x6b, 0xeb, 0x7a, 0x66 // sbc al r6 r11 r10 ROR 25
};
const byte kInstruction_sbc_al_r8_r3_r9_ROR_15[] = {
  0x63, 0xeb, 0xf9, 0x38 // sbc al r8 r3 r9 ROR 15
};
const byte kInstruction_sbc_al_r3_r12_r14_LSL_23[] = {
  0x6c, 0xeb, 0xce, 0x53 // sbc al r3 r12 r14 LSL 23
};
const byte kInstruction_sbc_al_r14_r14_r6_ROR_23[] = {
  0x6e, 0xeb, 0xf6, 0x5e // sbc al r14 r14 r6 ROR 23
};
const byte kInstruction_sbc_al_r6_r8_r8_ROR_25[] = {
  0x68, 0xeb, 0x78, 0x66 // sbc al r6 r8 r8 ROR 25
};
const byte kInstruction_sbc_al_r5_r5_r2_LSL_17[] = {
  0x65, 0xeb, 0x42, 0x45 // sbc al r5 r5 r2 LSL 17
};
const byte kInstruction_sbc_al_r13_r4_r6_ROR_13[] = {
  0x64, 0xeb, 0x76, 0x3d // sbc al r13 r4 r6 ROR 13
};
const byte kInstruction_sbc_al_r10_r9_r0_LSL_25[] = {
  0x69, 0xeb, 0x40, 0x6a // sbc al r10 r9 r0 LSL 25
};
const byte kInstruction_sbc_al_r11_r2_r5_ROR_15[] = {
  0x62, 0xeb, 0xf5, 0x3b // sbc al r11 r2 r5 ROR 15
};
const byte kInstruction_sbc_al_r4_r13_r4_LSL_8[] = {
  0x6d, 0xeb, 0x04, 0x24 // sbc al r4 r13 r4 LSL 8
};
const byte kInstruction_sbc_al_r13_r6_r5_LSL_31[] = {
  0x66, 0xeb, 0xc5, 0x7d // sbc al r13 r6 r5 LSL 31
};
const byte kInstruction_sbc_al_r3_r5_r6_ROR_25[] = {
  0x65, 0xeb, 0x76, 0x63 // sbc al r3 r5 r6 ROR 25
};
const byte kInstruction_sbc_al_r7_r7_r12_ROR_12[] = {
  0x67, 0xeb, 0x3c, 0x37 // sbc al r7 r7 r12 ROR 12
};
const byte kInstruction_sbc_al_r6_r10_r6_ROR_18[] = {
  0x6a, 0xeb, 0xb6, 0x46 // sbc al r6 r10 r6 ROR 18
};
const byte kInstruction_sbc_al_r8_r14_r14_LSL_30[] = {
  0x6e, 0xeb, 0x8e, 0x78 // sbc al r8 r14 r14 LSL 30
};
const byte kInstruction_sbc_al_r0_r0_r2_LSL_4[] = {
  0x60, 0xeb, 0x02, 0x10 // sbc al r0 r0 r2 LSL 4
};
const byte kInstruction_sbc_al_r11_r2_r3_ROR_10[] = {
  0x62, 0xeb, 0xb3, 0x2b // sbc al r11 r2 r3 ROR 10
};
const byte kInstruction_sbc_al_r2_r6_r14_ROR_29[] = {
  0x66, 0xeb, 0x7e, 0x72 // sbc al r2 r6 r14 ROR 29
};
const byte kInstruction_sbc_al_r4_r5_r11_ROR_22[] = {
  0x65, 0xeb, 0xbb, 0x54 // sbc al r4 r5 r11 ROR 22
};
const byte kInstruction_sbc_al_r13_r5_r1_LSL_8[] = {
  0x65, 0xeb, 0x01, 0x2d // sbc al r13 r5 r1 LSL 8
};
const byte kInstruction_sbc_al_r9_r3_r0_ROR_25[] = {
  0x63, 0xeb, 0x70, 0x69 // sbc al r9 r3 r0 ROR 25
};
const byte kInstruction_sbc_al_r10_r0_r14_LSL_11[] = {
  0x60, 0xeb, 0xce, 0x2a // sbc al r10 r0 r14 LSL 11
};
const byte kInstruction_sbc_al_r8_r13_r13_ROR_6[] = {
  0x6d, 0xeb, 0xbd, 0x18 // sbc al r8 r13 r13 ROR 6
};
const byte kInstruction_sbc_al_r10_r7_r14_LSL_10[] = {
  0x67, 0xeb, 0x8e, 0x2a // sbc al r10 r7 r14 LSL 10
};
const byte kInstruction_sbc_al_r9_r6_r12_ROR_31[] = {
  0x66, 0xeb, 0xfc, 0x79 // sbc al r9 r6 r12 ROR 31
};
const byte kInstruction_sbc_al_r9_r5_r0_ROR_1[] = {
  0x65, 0xeb, 0x70, 0x09 // sbc al r9 r5 r0 ROR 1
};
const byte kInstruction_sbc_al_r0_r10_r12_LSL_11[] = {
  0x6a, 0xeb, 0xcc, 0x20 // sbc al r0 r10 r12 LSL 11
};
const byte kInstruction_sbc_al_r8_r0_r8_ROR_15[] = {
  0x60, 0xeb, 0xf8, 0x38 // sbc al r8 r0 r8 ROR 15
};
const byte kInstruction_sbc_al_r13_r2_r1_LSL_21[] = {
  0x62, 0xeb, 0x41, 0x5d // sbc al r13 r2 r1 LSL 21
};
const byte kInstruction_sbc_al_r3_r0_r9_LSL_29[] = {
  0x60, 0xeb, 0x49, 0x73 // sbc al r3 r0 r9 LSL 29
};
const byte kInstruction_sbc_al_r14_r10_r11_LSL_17[] = {
  0x6a, 0xeb, 0x4b, 0x4e // sbc al r14 r10 r11 LSL 17
};
const byte kInstruction_sbc_al_r13_r4_r0_LSL_17[] = {
  0x64, 0xeb, 0x40, 0x4d // sbc al r13 r4 r0 LSL 17
};
const byte kInstruction_sbc_al_r0_r3_r4_LSL_6[] = {
  0x63, 0xeb, 0x84, 0x10 // sbc al r0 r3 r4 LSL 6
};
const byte kInstruction_sbc_al_r13_r9_r2_LSL_21[] = {
  0x69, 0xeb, 0x42, 0x5d // sbc al r13 r9 r2 LSL 21
};
const byte kInstruction_sbc_al_r13_r5_r13_LSL_23[] = {
  0x65, 0xeb, 0xcd, 0x5d // sbc al r13 r5 r13 LSL 23
};
const byte kInstruction_sbc_al_r14_r10_r2_LSL_8[] = {
  0x6a, 0xeb, 0x02, 0x2e // sbc al r14 r10 r2 LSL 8
};
const byte kInstruction_sbc_al_r12_r11_r12_LSL_13[] = {
  0x6b, 0xeb, 0x4c, 0x3c // sbc al r12 r11 r12 LSL 13
};
const byte kInstruction_sbc_al_r10_r2_r12_ROR_23[] = {
  0x62, 0xeb, 0xfc, 0x5a // sbc al r10 r2 r12 ROR 23
};
const byte kInstruction_sbc_al_r5_r5_r8_ROR_28[] = {
  0x65, 0xeb, 0x38, 0x75 // sbc al r5 r5 r8 ROR 28
};
const byte kInstruction_sbc_al_r0_r14_r12_ROR_19[] = {
  0x6e, 0xeb, 0xfc, 0x40 // sbc al r0 r14 r12 ROR 19
};
const byte kInstruction_sbc_al_r8_r13_r11_LSL_24[] = {
  0x6d, 0xeb, 0x0b, 0x68 // sbc al r8 r13 r11 LSL 24
};
const byte kInstruction_sbc_al_r9_r5_r3_ROR_30[] = {
  0x65, 0xeb, 0xb3, 0x79 // sbc al r9 r5 r3 ROR 30
};
const byte kInstruction_sbc_al_r9_r10_r7_ROR_22[] = {
  0x6a, 0xeb, 0xb7, 0x59 // sbc al r9 r10 r7 ROR 22
};
const byte kInstruction_sbc_al_r10_r3_r10_LSL_18[] = {
  0x63, 0xeb, 0x8a, 0x4a // sbc al r10 r3 r10 LSL 18
};
const byte kInstruction_sbc_al_r7_r3_r14_ROR_22[] = {
  0x63, 0xeb, 0xbe, 0x57 // sbc al r7 r3 r14 ROR 22
};
const byte kInstruction_sbc_al_r11_r4_r4_LSL_20[] = {
  0x64, 0xeb, 0x04, 0x5b // sbc al r11 r4 r4 LSL 20
};
const byte kInstruction_sbc_al_r7_r13_r14_ROR_25[] = {
  0x6d, 0xeb, 0x7e, 0x67 // sbc al r7 r13 r14 ROR 25
};
const byte kInstruction_sbc_al_r10_r10_r1_ROR_5[] = {
  0x6a, 0xeb, 0x71, 0x1a // sbc al r10 r10 r1 ROR 5
};
const byte kInstruction_sbc_al_r4_r12_r6_LSL_6[] = {
  0x6c, 0xeb, 0x86, 0x14 // sbc al r4 r12 r6 LSL 6
};
const byte kInstruction_sbc_al_r3_r6_r9_ROR_3[] = {
  0x66, 0xeb, 0xf9, 0x03 // sbc al r3 r6 r9 ROR 3
};
const byte kInstruction_sbc_al_r14_r3_r7_LSL_26[] = {
  0x63, 0xeb, 0x87, 0x6e // sbc al r14 r3 r7 LSL 26
};
const byte kInstruction_sbc_al_r0_r8_r10_LSL_10[] = {
  0x68, 0xeb, 0x8a, 0x20 // sbc al r0 r8 r10 LSL 10
};
const byte kInstruction_sbc_al_r13_r10_r7_ROR_19[] = {
  0x6a, 0xeb, 0xf7, 0x4d // sbc al r13 r10 r7 ROR 19
};
const byte kInstruction_sbc_al_r14_r1_r6_ROR_27[] = {
  0x61, 0xeb, 0xf6, 0x6e // sbc al r14 r1 r6 ROR 27
};
const byte kInstruction_sbc_al_r0_r5_r13_LSL_18[] = {
  0x65, 0xeb, 0x8d, 0x40 // sbc al r0 r5 r13 LSL 18
};
const byte kInstruction_sbc_al_r10_r9_r0_LSL_15[] = {
  0x69, 0xeb, 0xc0, 0x3a // sbc al r10 r9 r0 LSL 15
};
const byte kInstruction_sbc_al_r12_r8_r13_ROR_19[] = {
  0x68, 0xeb, 0xfd, 0x4c // sbc al r12 r8 r13 ROR 19
};
const byte kInstruction_sbc_al_r8_r0_r11_LSL_31[] = {
  0x60, 0xeb, 0xcb, 0x78 // sbc al r8 r0 r11 LSL 31
};
const byte kInstruction_sbc_al_r8_r14_r0_ROR_20[] = {
  0x6e, 0xeb, 0x30, 0x58 // sbc al r8 r14 r0 ROR 20
};
const byte kInstruction_sbc_al_r8_r7_r6_ROR_14[] = {
  0x67, 0xeb, 0xb6, 0x38 // sbc al r8 r7 r6 ROR 14
};
const byte kInstruction_sbc_al_r10_r9_r5_LSL_21[] = {
  0x69, 0xeb, 0x45, 0x5a // sbc al r10 r9 r5 LSL 21
};
const byte kInstruction_sbc_al_r9_r8_r13_ROR_28[] = {
  0x68, 0xeb, 0x3d, 0x79 // sbc al r9 r8 r13 ROR 28
};
const byte kInstruction_sbc_al_r12_r12_r12_ROR_25[] = {
  0x6c, 0xeb, 0x7c, 0x6c // sbc al r12 r12 r12 ROR 25
};
const byte kInstruction_sbc_al_r5_r11_r4_ROR_12[] = {
  0x6b, 0xeb, 0x34, 0x35 // sbc al r5 r11 r4 ROR 12
};
const byte kInstruction_sbc_al_r1_r7_r10_ROR_13[] = {
  0x67, 0xeb, 0x7a, 0x31 // sbc al r1 r7 r10 ROR 13
};
const byte kInstruction_sbc_al_r14_r12_r2_LSL_19[] = {
  0x6c, 0xeb, 0xc2, 0x4e // sbc al r14 r12 r2 LSL 19
};
const byte kInstruction_sbc_al_r0_r5_r14_LSL_20[] = {
  0x65, 0xeb, 0x0e, 0x50 // sbc al r0 r5 r14 LSL 20
};
const byte kInstruction_sbc_al_r12_r4_r3_ROR_27[] = {
  0x64, 0xeb, 0xf3, 0x6c // sbc al r12 r4 r3 ROR 27
};
const byte kInstruction_sbc_al_r9_r3_r1_ROR_22[] = {
  0x63, 0xeb, 0xb1, 0x59 // sbc al r9 r3 r1 ROR 22
};
const byte kInstruction_sbc_al_r2_r12_r7_ROR_23[] = {
  0x6c, 0xeb, 0xf7, 0x52 // sbc al r2 r12 r7 ROR 23
};
const byte kInstruction_sbc_al_r10_r4_r8_ROR_11[] = {
  0x64, 0xeb, 0xf8, 0x2a // sbc al r10 r4 r8 ROR 11
};
const byte kInstruction_sbc_al_r6_r0_r2_LSL_8[] = {
  0x60, 0xeb, 0x02, 0x26 // sbc al r6 r0 r2 LSL 8
};
const byte kInstruction_sbc_al_r10_r3_r0_LSL_1[] = {
  0x63, 0xeb, 0x40, 0x0a // sbc al r10 r3 r0 LSL 1
};
const byte kInstruction_sbc_al_r6_r6_r4_LSL_1[] = {
  0x66, 0xeb, 0x44, 0x06 // sbc al r6 r6 r4 LSL 1
};
const byte kInstruction_sbc_al_r13_r12_r13_ROR_13[] = {
  0x6c, 0xeb, 0x7d, 0x3d // sbc al r13 r12 r13 ROR 13
};
const byte kInstruction_sbc_al_r0_r9_r10_ROR_1[] = {
  0x69, 0xeb, 0x7a, 0x00 // sbc al r0 r9 r10 ROR 1
};
const byte kInstruction_sbc_al_r9_r13_r9_ROR_16[] = {
  0x6d, 0xeb, 0x39, 0x49 // sbc al r9 r13 r9 ROR 16
};
const byte kInstruction_sbc_al_r0_r6_r2_LSL_4[] = {
  0x66, 0xeb, 0x02, 0x10 // sbc al r0 r6 r2 LSL 4
};
const byte kInstruction_sbc_al_r9_r2_r11_LSL_31[] = {
  0x62, 0xeb, 0xcb, 0x79 // sbc al r9 r2 r11 LSL 31
};
const byte kInstruction_sbc_al_r12_r12_r13_ROR_19[] = {
  0x6c, 0xeb, 0xfd, 0x4c // sbc al r12 r12 r13 ROR 19
};
const byte kInstruction_sbc_al_r7_r14_r2_ROR_23[] = {
  0x6e, 0xeb, 0xf2, 0x57 // sbc al r7 r14 r2 ROR 23
};
const byte kInstruction_sbc_al_r7_r1_r3_LSL_26[] = {
  0x61, 0xeb, 0x83, 0x67 // sbc al r7 r1 r3 LSL 26
};
const byte kInstruction_sbc_al_r13_r6_r12_ROR_26[] = {
  0x66, 0xeb, 0xbc, 0x6d // sbc al r13 r6 r12 ROR 26
};
const byte kInstruction_sbc_al_r10_r14_r12_ROR_5[] = {
  0x6e, 0xeb, 0x7c, 0x1a // sbc al r10 r14 r12 ROR 5
};
const byte kInstruction_sbc_al_r5_r9_r12_LSL_9[] = {
  0x69, 0xeb, 0x4c, 0x25 // sbc al r5 r9 r12 LSL 9
};
const byte kInstruction_sbc_al_r2_r7_r2_ROR_10[] = {
  0x67, 0xeb, 0xb2, 0x22 // sbc al r2 r7 r2 ROR 10
};
const byte kInstruction_sbc_al_r12_r12_r8_ROR_6[] = {
  0x6c, 0xeb, 0xb8, 0x1c // sbc al r12 r12 r8 ROR 6
};
const byte kInstruction_sbc_al_r1_r13_r13_ROR_24[] = {
  0x6d, 0xeb, 0x3d, 0x61 // sbc al r1 r13 r13 ROR 24
};
const byte kInstruction_sbc_al_r6_r10_r10_ROR_26[] = {
  0x6a, 0xeb, 0xba, 0x66 // sbc al r6 r10 r10 ROR 26
};
const byte kInstruction_sbc_al_r13_r9_r1_LSL_18[] = {
  0x69, 0xeb, 0x81, 0x4d // sbc al r13 r9 r1 LSL 18
};
const byte kInstruction_sbc_al_r6_r1_r4_ROR_21[] = {
  0x61, 0xeb, 0x74, 0x56 // sbc al r6 r1 r4 ROR 21
};
const byte kInstruction_sbc_al_r0_r3_r3_ROR_18[] = {
  0x63, 0xeb, 0xb3, 0x40 // sbc al r0 r3 r3 ROR 18
};
const byte kInstruction_sbc_al_r1_r9_r5_LSL_29[] = {
  0x69, 0xeb, 0x45, 0x71 // sbc al r1 r9 r5 LSL 29
};
const byte kInstruction_sbc_al_r11_r8_r7_ROR_18[] = {
  0x68, 0xeb, 0xb7, 0x4b // sbc al r11 r8 r7 ROR 18
};
const byte kInstruction_sbc_al_r2_r3_r12_LSL_7[] = {
  0x63, 0xeb, 0xcc, 0x12 // sbc al r2 r3 r12 LSL 7
};
const byte kInstruction_sbc_al_r8_r3_r9_LSL_18[] = {
  0x63, 0xeb, 0x89, 0x48 // sbc al r8 r3 r9 LSL 18
};
const byte kInstruction_sbc_al_r8_r12_r1_LSL_11[] = {
  0x6c, 0xeb, 0xc1, 0x28 // sbc al r8 r12 r1 LSL 11
};
const byte kInstruction_sbc_al_r14_r9_r5_ROR_21[] = {
  0x69, 0xeb, 0x75, 0x5e // sbc al r14 r9 r5 ROR 21
};
const byte kInstruction_sbc_al_r0_r6_r12_ROR_26[] = {
  0x66, 0xeb, 0xbc, 0x60 // sbc al r0 r6 r12 ROR 26
};
const byte kInstruction_sbc_al_r3_r6_r14_LSL_14[] = {
  0x66, 0xeb, 0x8e, 0x33 // sbc al r3 r6 r14 LSL 14
};
const byte kInstruction_sbc_al_r11_r0_r9_LSL_9[] = {
  0x60, 0xeb, 0x49, 0x2b // sbc al r11 r0 r9 LSL 9
};
const byte kInstruction_sbc_al_r8_r13_r7_LSL_9[] = {
  0x6d, 0xeb, 0x47, 0x28 // sbc al r8 r13 r7 LSL 9
};
const byte kInstruction_sbc_al_r3_r1_r13_LSL_23[] = {
  0x61, 0xeb, 0xcd, 0x53 // sbc al r3 r1 r13 LSL 23
};
const byte kInstruction_sbc_al_r12_r13_r13_ROR_4[] = {
  0x6d, 0xeb, 0x3d, 0x1c // sbc al r12 r13 r13 ROR 4
};
const byte kInstruction_sbc_al_r10_r14_r9_ROR_13[] = {
  0x6e, 0xeb, 0x79, 0x3a // sbc al r10 r14 r9 ROR 13
};
const byte kInstruction_sbc_al_r14_r5_r1_LSL_22[] = {
  0x65, 0xeb, 0x81, 0x5e // sbc al r14 r5 r1 LSL 22
};
const byte kInstruction_sbc_al_r11_r8_r8_ROR_28[] = {
  0x68, 0xeb, 0x38, 0x7b // sbc al r11 r8 r8 ROR 28
};
const byte kInstruction_sbc_al_r0_r8_r12_ROR_19[] = {
  0x68, 0xeb, 0xfc, 0x40 // sbc al r0 r8 r12 ROR 19
};
const byte kInstruction_sbc_al_r11_r3_r1_ROR_6[] = {
  0x63, 0xeb, 0xb1, 0x1b // sbc al r11 r3 r1 ROR 6
};
const byte kInstruction_sbc_al_r2_r7_r2_ROR_5[] = {
  0x67, 0xeb, 0x72, 0x12 // sbc al r2 r7 r2 ROR 5
};
const byte kInstruction_sbc_al_r11_r14_r2_ROR_14[] = {
  0x6e, 0xeb, 0xb2, 0x3b // sbc al r11 r14 r2 ROR 14
};
const byte kInstruction_sbc_al_r9_r13_r7_LSL_27[] = {
  0x6d, 0xeb, 0xc7, 0x69 // sbc al r9 r13 r7 LSL 27
};
const byte kInstruction_sbc_al_r0_r0_r3_ROR_29[] = {
  0x60, 0xeb, 0x73, 0x70 // sbc al r0 r0 r3 ROR 29
};
const byte kInstruction_sbc_al_r9_r12_r7_LSL_24[] = {
  0x6c, 0xeb, 0x07, 0x69 // sbc al r9 r12 r7 LSL 24
};
const byte kInstruction_sbc_al_r8_r5_r4_LSL_10[] = {
  0x65, 0xeb, 0x84, 0x28 // sbc al r8 r5 r4 LSL 10
};
const byte kInstruction_sbc_al_r0_r2_r12_ROR_10[] = {
  0x62, 0xeb, 0xbc, 0x20 // sbc al r0 r2 r12 ROR 10
};
const byte kInstruction_sbc_al_r6_r0_r5_ROR_16[] = {
  0x60, 0xeb, 0x35, 0x46 // sbc al r6 r0 r5 ROR 16
};
const byte kInstruction_sbc_al_r9_r9_r14_ROR_2[] = {
  0x69, 0xeb, 0xbe, 0x09 // sbc al r9 r9 r14 ROR 2
};
const byte kInstruction_sbc_al_r0_r0_r7_ROR_28[] = {
  0x60, 0xeb, 0x37, 0x70 // sbc al r0 r0 r7 ROR 28
};
const byte kInstruction_sbc_al_r2_r11_r12_LSL_16[] = {
  0x6b, 0xeb, 0x0c, 0x42 // sbc al r2 r11 r12 LSL 16
};
const byte kInstruction_sbc_al_r14_r0_r8_ROR_13[] = {
  0x60, 0xeb, 0x78, 0x3e // sbc al r14 r0 r8 ROR 13
};
const byte kInstruction_sbc_al_r3_r4_r3_LSL_2[] = {
  0x64, 0xeb, 0x83, 0x03 // sbc al r3 r4 r3 LSL 2
};
const byte kInstruction_sbc_al_r11_r6_r4_ROR_25[] = {
  0x66, 0xeb, 0x74, 0x6b // sbc al r11 r6 r4 ROR 25
};
const byte kInstruction_sbc_al_r14_r1_r12_LSL_4[] = {
  0x61, 0xeb, 0x0c, 0x1e // sbc al r14 r1 r12 LSL 4
};
const byte kInstruction_sbc_al_r9_r2_r6_LSL_12[] = {
  0x62, 0xeb, 0x06, 0x39 // sbc al r9 r2 r6 LSL 12
};
const byte kInstruction_sbc_al_r10_r9_r2_ROR_26[] = {
  0x69, 0xeb, 0xb2, 0x6a // sbc al r10 r9 r2 ROR 26
};
const byte kInstruction_sbc_al_r2_r3_r10_ROR_2[] = {
  0x63, 0xeb, 0xba, 0x02 // sbc al r2 r3 r10 ROR 2
};
const byte kInstruction_sbc_al_r6_r7_r9_LSL_12[] = {
  0x67, 0xeb, 0x09, 0x36 // sbc al r6 r7 r9 LSL 12
};
const byte kInstruction_sbc_al_r4_r1_r7_LSL_6[] = {
  0x61, 0xeb, 0x87, 0x14 // sbc al r4 r1 r7 LSL 6
};
const byte kInstruction_sbc_al_r4_r3_r13_ROR_31[] = {
  0x63, 0xeb, 0xfd, 0x74 // sbc al r4 r3 r13 ROR 31
};
const byte kInstruction_sbc_al_r14_r1_r0_ROR_11[] = {
  0x61, 0xeb, 0xf0, 0x2e // sbc al r14 r1 r0 ROR 11
};
const byte kInstruction_sbc_al_r4_r3_r9_ROR_18[] = {
  0x63, 0xeb, 0xb9, 0x44 // sbc al r4 r3 r9 ROR 18
};
const byte kInstruction_sbc_al_r4_r5_r2_ROR_26[] = {
  0x65, 0xeb, 0xb2, 0x64 // sbc al r4 r5 r2 ROR 26
};
const byte kInstruction_sbc_al_r11_r13_r9_LSL_1[] = {
  0x6d, 0xeb, 0x49, 0x0b // sbc al r11 r13 r9 LSL 1
};
const byte kInstruction_sbc_al_r6_r13_r8_LSL_31[] = {
  0x6d, 0xeb, 0xc8, 0x76 // sbc al r6 r13 r8 LSL 31
};
const byte kInstruction_sbc_al_r8_r6_r5_LSL_7[] = {
  0x66, 0xeb, 0xc5, 0x18 // sbc al r8 r6 r5 LSL 7
};
const byte kInstruction_sbc_al_r3_r12_r11_LSL_29[] = {
  0x6c, 0xeb, 0x4b, 0x73 // sbc al r3 r12 r11 LSL 29
};
const byte kInstruction_sbc_al_r4_r11_r3_ROR_25[] = {
  0x6b, 0xeb, 0x73, 0x64 // sbc al r4 r11 r3 ROR 25
};
const byte kInstruction_sbc_al_r11_r0_r3_ROR_1[] = {
  0x60, 0xeb, 0x73, 0x0b // sbc al r11 r0 r3 ROR 1
};
const byte kInstruction_sbc_al_r10_r7_r8_ROR_14[] = {
  0x67, 0xeb, 0xb8, 0x3a // sbc al r10 r7 r8 ROR 14
};
const byte kInstruction_sbc_al_r12_r8_r5_ROR_17[] = {
  0x68, 0xeb, 0x75, 0x4c // sbc al r12 r8 r5 ROR 17
};
const byte kInstruction_sbc_al_r13_r11_r1_LSL_26[] = {
  0x6b, 0xeb, 0x81, 0x6d // sbc al r13 r11 r1 LSL 26
};
const byte kInstruction_sbc_al_r13_r4_r5_ROR_26[] = {
  0x64, 0xeb, 0xb5, 0x6d // sbc al r13 r4 r5 ROR 26
};
const byte kInstruction_sbc_al_r12_r5_r8_ROR_17[] = {
  0x65, 0xeb, 0x78, 0x4c // sbc al r12 r5 r8 ROR 17
};
const byte kInstruction_sbc_al_r12_r0_r10_ROR_16[] = {
  0x60, 0xeb, 0x3a, 0x4c // sbc al r12 r0 r10 ROR 16
};
const byte kInstruction_sbc_al_r6_r4_r14_ROR_28[] = {
  0x64, 0xeb, 0x3e, 0x76 // sbc al r6 r4 r14 ROR 28
};
const byte kInstruction_sbc_al_r13_r13_r5_LSL_16[] = {
  0x6d, 0xeb, 0x05, 0x4d // sbc al r13 r13 r5 LSL 16
};
const byte kInstruction_sbc_al_r9_r6_r10_LSL_15[] = {
  0x66, 0xeb, 0xca, 0x39 // sbc al r9 r6 r10 LSL 15
};
const byte kInstruction_sbc_al_r2_r10_r8_LSL_16[] = {
  0x6a, 0xeb, 0x08, 0x42 // sbc al r2 r10 r8 LSL 16
};
const byte kInstruction_sbc_al_r11_r4_r0_LSL_5[] = {
  0x64, 0xeb, 0x40, 0x1b // sbc al r11 r4 r0 LSL 5
};
const byte kInstruction_sbc_al_r9_r2_r14_ROR_31[] = {
  0x62, 0xeb, 0xfe, 0x79 // sbc al r9 r2 r14 ROR 31
};
const byte kInstruction_sbc_al_r0_r7_r11_LSL_25[] = {
  0x67, 0xeb, 0x4b, 0x60 // sbc al r0 r7 r11 LSL 25
};
const byte kInstruction_sbc_al_r2_r6_r12_LSL_8[] = {
  0x66, 0xeb, 0x0c, 0x22 // sbc al r2 r6 r12 LSL 8
};
const byte kInstruction_sbc_al_r1_r10_r4_ROR_7[] = {
  0x6a, 0xeb, 0xf4, 0x11 // sbc al r1 r10 r4 ROR 7
};
const byte kInstruction_sbc_al_r4_r3_r7_LSL_10[] = {
  0x63, 0xeb, 0x87, 0x24 // sbc al r4 r3 r7 LSL 10
};
const byte kInstruction_sbc_al_r6_r7_r11_LSL_14[] = {
  0x67, 0xeb, 0x8b, 0x36 // sbc al r6 r7 r11 LSL 14
};
const byte kInstruction_sbc_al_r9_r10_r0_LSL_31[] = {
  0x6a, 0xeb, 0xc0, 0x79 // sbc al r9 r10 r0 LSL 31
};
const byte kInstruction_sbc_al_r5_r5_r13_LSL_2[] = {
  0x65, 0xeb, 0x8d, 0x05 // sbc al r5 r5 r13 LSL 2
};
const byte kInstruction_sbc_al_r7_r10_r2_LSL_26[] = {
  0x6a, 0xeb, 0x82, 0x67 // sbc al r7 r10 r2 LSL 26
};
const byte kInstruction_sbc_al_r3_r7_r7_LSL_29[] = {
  0x67, 0xeb, 0x47, 0x73 // sbc al r3 r7 r7 LSL 29
};
const byte kInstruction_sbc_al_r4_r1_r8_LSL_18[] = {
  0x61, 0xeb, 0x88, 0x44 // sbc al r4 r1 r8 LSL 18
};
const byte kInstruction_sbc_al_r14_r12_r2_LSL_29[] = {
  0x6c, 0xeb, 0x42, 0x7e // sbc al r14 r12 r2 LSL 29
};
const byte kInstruction_sbc_al_r11_r6_r3_ROR_8[] = {
  0x66, 0xeb, 0x33, 0x2b // sbc al r11 r6 r3 ROR 8
};
const byte kInstruction_sbc_al_r14_r5_r3_LSL_7[] = {
  0x65, 0xeb, 0xc3, 0x1e // sbc al r14 r5 r3 LSL 7
};
const byte kInstruction_sbc_al_r6_r13_r12_LSL_2[] = {
  0x6d, 0xeb, 0x8c, 0x06 // sbc al r6 r13 r12 LSL 2
};
const byte kInstruction_sbc_al_r9_r1_r0_ROR_13[] = {
  0x61, 0xeb, 0x70, 0x39 // sbc al r9 r1 r0 ROR 13
};
const byte kInstruction_sbc_al_r9_r5_r7_LSL_16[] = {
  0x65, 0xeb, 0x07, 0x49 // sbc al r9 r5 r7 LSL 16
};
const byte kInstruction_sbc_al_r2_r6_r0_ROR_27[] = {
  0x66, 0xeb, 0xf0, 0x62 // sbc al r2 r6 r0 ROR 27
};
const byte kInstruction_sbc_al_r4_r9_r5_LSL_19[] = {
  0x69, 0xeb, 0xc5, 0x44 // sbc al r4 r9 r5 LSL 19
};
const byte kInstruction_sbc_al_r9_r5_r13_ROR_26[] = {
  0x65, 0xeb, 0xbd, 0x69 // sbc al r9 r5 r13 ROR 26
};
const byte kInstruction_sbc_al_r4_r9_r14_LSL_25[] = {
  0x69, 0xeb, 0x4e, 0x64 // sbc al r4 r9 r14 LSL 25
};
const byte kInstruction_sbc_al_r7_r13_r1_LSL_22[] = {
  0x6d, 0xeb, 0x81, 0x57 // sbc al r7 r13 r1 LSL 22
};
const byte kInstruction_sbc_al_r14_r13_r6_LSL_25[] = {
  0x6d, 0xeb, 0x46, 0x6e // sbc al r14 r13 r6 LSL 25
};
const byte kInstruction_sbc_al_r14_r12_r14_ROR_1[] = {
  0x6c, 0xeb, 0x7e, 0x0e // sbc al r14 r12 r14 ROR 1
};
const byte kInstruction_sbc_al_r9_r7_r4_ROR_28[] = {
  0x67, 0xeb, 0x34, 0x79 // sbc al r9 r7 r4 ROR 28
};
const byte kInstruction_sbc_al_r13_r14_r11_ROR_4[] = {
  0x6e, 0xeb, 0x3b, 0x1d // sbc al r13 r14 r11 ROR 4
};
const byte kInstruction_sbc_al_r14_r6_r14_LSL_22[] = {
  0x66, 0xeb, 0x8e, 0x5e // sbc al r14 r6 r14 LSL 22
};
const byte kInstruction_sbc_al_r9_r10_r13_LSL_27[] = {
  0x6a, 0xeb, 0xcd, 0x69 // sbc al r9 r10 r13 LSL 27
};
const byte kInstruction_sbc_al_r12_r1_r7_LSL_17[] = {
  0x61, 0xeb, 0x47, 0x4c // sbc al r12 r1 r7 LSL 17
};
const byte kInstruction_sbc_al_r8_r0_r5_ROR_6[] = {
  0x60, 0xeb, 0xb5, 0x18 // sbc al r8 r0 r5 ROR 6
};
const byte kInstruction_sbc_al_r3_r11_r6_LSL_6[] = {
  0x6b, 0xeb, 0x86, 0x13 // sbc al r3 r11 r6 LSL 6
};
const byte kInstruction_sbc_al_r13_r5_r7_LSL_23[] = {
  0x65, 0xeb, 0xc7, 0x5d // sbc al r13 r5 r7 LSL 23
};
const byte kInstruction_sbc_al_r13_r8_r1_ROR_20[] = {
  0x68, 0xeb, 0x31, 0x5d // sbc al r13 r8 r1 ROR 20
};
const byte kInstruction_sbc_al_r13_r0_r7_LSL_10[] = {
  0x60, 0xeb, 0x87, 0x2d // sbc al r13 r0 r7 LSL 10
};
const byte kInstruction_sbc_al_r7_r1_r12_ROR_17[] = {
  0x61, 0xeb, 0x7c, 0x47 // sbc al r7 r1 r12 ROR 17
};
const byte kInstruction_sbc_al_r5_r3_r12_LSL_12[] = {
  0x63, 0xeb, 0x0c, 0x35 // sbc al r5 r3 r12 LSL 12
};
const byte kInstruction_sbc_al_r0_r12_r4_LSL_6[] = {
  0x6c, 0xeb, 0x84, 0x10 // sbc al r0 r12 r4 LSL 6
};
const byte kInstruction_sbc_al_r7_r11_r11_ROR_8[] = {
  0x6b, 0xeb, 0x3b, 0x27 // sbc al r7 r11 r11 ROR 8
};
const byte kInstruction_sbc_al_r3_r0_r0_LSL_17[] = {
  0x60, 0xeb, 0x40, 0x43 // sbc al r3 r0 r0 LSL 17
};
const byte kInstruction_sbc_al_r4_r12_r0_ROR_2[] = {
  0x6c, 0xeb, 0xb0, 0x04 // sbc al r4 r12 r0 ROR 2
};
const byte kInstruction_sbc_al_r6_r3_r3_LSL_25[] = {
  0x63, 0xeb, 0x43, 0x66 // sbc al r6 r3 r3 LSL 25
};
const byte kInstruction_sbc_al_r9_r5_r5_LSL_9[] = {
  0x65, 0xeb, 0x45, 0x29 // sbc al r9 r5 r5 LSL 9
};
const byte kInstruction_sbc_al_r7_r3_r4_LSL_20[] = {
  0x63, 0xeb, 0x04, 0x57 // sbc al r7 r3 r4 LSL 20
};
const byte kInstruction_sbc_al_r12_r1_r7_ROR_6[] = {
  0x61, 0xeb, 0xb7, 0x1c // sbc al r12 r1 r7 ROR 6
};
const byte kInstruction_sbc_al_r2_r14_r7_LSL_23[] = {
  0x6e, 0xeb, 0xc7, 0x52 // sbc al r2 r14 r7 LSL 23
};
const byte kInstruction_sbc_al_r9_r6_r9_ROR_22[] = {
  0x66, 0xeb, 0xb9, 0x59 // sbc al r9 r6 r9 ROR 22
};
const byte kInstruction_sbc_al_r1_r8_r2_ROR_11[] = {
  0x68, 0xeb, 0xf2, 0x21 // sbc al r1 r8 r2 ROR 11
};
const byte kInstruction_sbc_al_r10_r2_r14_ROR_15[] = {
  0x62, 0xeb, 0xfe, 0x3a // sbc al r10 r2 r14 ROR 15
};
const byte kInstruction_sbc_al_r9_r1_r9_ROR_27[] = {
  0x61, 0xeb, 0xf9, 0x69 // sbc al r9 r1 r9 ROR 27
};
const byte kInstruction_sbc_al_r12_r11_r13_ROR_30[] = {
  0x6b, 0xeb, 0xbd, 0x7c // sbc al r12 r11 r13 ROR 30
};
const byte kInstruction_sbc_al_r13_r11_r1_ROR_5[] = {
  0x6b, 0xeb, 0x71, 0x1d // sbc al r13 r11 r1 ROR 5
};
const byte kInstruction_sbc_al_r12_r8_r10_LSL_24[] = {
  0x68, 0xeb, 0x0a, 0x6c // sbc al r12 r8 r10 LSL 24
};
const byte kInstruction_sbc_al_r8_r6_r10_ROR_19[] = {
  0x66, 0xeb, 0xfa, 0x48 // sbc al r8 r6 r10 ROR 19
};
const byte kInstruction_sbc_al_r0_r0_r2_ROR_26[] = {
  0x60, 0xeb, 0xb2, 0x60 // sbc al r0 r0 r2 ROR 26
};
const byte kInstruction_sbc_al_r7_r14_r10_LSL_28[] = {
  0x6e, 0xeb, 0x0a, 0x77 // sbc al r7 r14 r10 LSL 28
};
const byte kInstruction_sbc_al_r3_r2_r12_LSL_12[] = {
  0x62, 0xeb, 0x0c, 0x33 // sbc al r3 r2 r12 LSL 12
};
const byte kInstruction_sbc_al_r9_r3_r8_ROR_29[] = {
  0x63, 0xeb, 0x78, 0x79 // sbc al r9 r3 r8 ROR 29
};
const byte kInstruction_sbc_al_r4_r11_r12_LSL_14[] = {
  0x6b, 0xeb, 0x8c, 0x34 // sbc al r4 r11 r12 LSL 14
};
const byte kInstruction_sbc_al_r7_r5_r11_ROR_9[] = {
  0x65, 0xeb, 0x7b, 0x27 // sbc al r7 r5 r11 ROR 9
};
const byte kInstruction_sbc_al_r12_r7_r7_ROR_2[] = {
  0x67, 0xeb, 0xb7, 0x0c // sbc al r12 r7 r7 ROR 2
};
const byte kInstruction_sbc_al_r3_r6_r9_ROR_24[] = {
  0x66, 0xeb, 0x39, 0x63 // sbc al r3 r6 r9 ROR 24
};
const byte kInstruction_sbc_al_r13_r14_r9_ROR_12[] = {
  0x6e, 0xeb, 0x39, 0x3d // sbc al r13 r14 r9 ROR 12
};
const byte kInstruction_sbc_al_r7_r3_r13_ROR_2[] = {
  0x63, 0xeb, 0xbd, 0x07 // sbc al r7 r3 r13 ROR 2
};
const byte kInstruction_sbc_al_r5_r11_r3_LSL_21[] = {
  0x6b, 0xeb, 0x43, 0x55 // sbc al r5 r11 r3 LSL 21
};
const byte kInstruction_sbc_al_r12_r9_r9_ROR_17[] = {
  0x69, 0xeb, 0x79, 0x4c // sbc al r12 r9 r9 ROR 17
};
const byte kInstruction_sbc_al_r0_r12_r13_ROR_3[] = {
  0x6c, 0xeb, 0xfd, 0x00 // sbc al r0 r12 r13 ROR 3
};
const byte kInstruction_sbc_al_r2_r4_r7_ROR_28[] = {
  0x64, 0xeb, 0x37, 0x72 // sbc al r2 r4 r7 ROR 28
};
const byte kInstruction_sbc_al_r11_r14_r8_LSL_5[] = {
  0x6e, 0xeb, 0x48, 0x1b // sbc al r11 r14 r8 LSL 5
};
const byte kInstruction_sbc_al_r14_r3_r14_ROR_11[] = {
  0x63, 0xeb, 0xfe, 0x2e // sbc al r14 r3 r14 ROR 11
};
const byte kInstruction_sbc_al_r3_r4_r9_LSL_10[] = {
  0x64, 0xeb, 0x89, 0x23 // sbc al r3 r4 r9 LSL 10
};
const byte kInstruction_sbc_al_r10_r5_r3_ROR_11[] = {
  0x65, 0xeb, 0xf3, 0x2a // sbc al r10 r5 r3 ROR 11
};
const byte kInstruction_sbc_al_r5_r12_r2_ROR_29[] = {
  0x6c, 0xeb, 0x72, 0x75 // sbc al r5 r12 r2 ROR 29
};
const byte kInstruction_sbc_al_r12_r10_r8_ROR_29[] = {
  0x6a, 0xeb, 0x78, 0x7c // sbc al r12 r10 r8 ROR 29
};
const byte kInstruction_sbc_al_r4_r2_r12_ROR_13[] = {
  0x62, 0xeb, 0x7c, 0x34 // sbc al r4 r2 r12 ROR 13
};
const byte kInstruction_sbc_al_r11_r7_r7_ROR_29[] = {
  0x67, 0xeb, 0x77, 0x7b // sbc al r11 r7 r7 ROR 29
};
const byte kInstruction_sbc_al_r12_r10_r2_ROR_20[] = {
  0x6a, 0xeb, 0x32, 0x5c // sbc al r12 r10 r2 ROR 20
};
const byte kInstruction_sbc_al_r0_r11_r3_LSL_6[] = {
  0x6b, 0xeb, 0x83, 0x10 // sbc al r0 r11 r3 LSL 6
};
const byte kInstruction_sbc_al_r12_r8_r10_ROR_13[] = {
  0x68, 0xeb, 0x7a, 0x3c // sbc al r12 r8 r10 ROR 13
};
const byte kInstruction_sbc_al_r2_r3_r9_LSL_30[] = {
  0x63, 0xeb, 0x89, 0x72 // sbc al r2 r3 r9 LSL 30
};
const byte kInstruction_sbc_al_r9_r5_r8_ROR_27[] = {
  0x65, 0xeb, 0xf8, 0x69 // sbc al r9 r5 r8 ROR 27
};
const byte kInstruction_sbc_al_r7_r3_r12_ROR_16[] = {
  0x63, 0xeb, 0x3c, 0x47 // sbc al r7 r3 r12 ROR 16
};
const byte kInstruction_sbc_al_r11_r8_r3_LSL_29[] = {
  0x68, 0xeb, 0x43, 0x7b // sbc al r11 r8 r3 LSL 29
};
const byte kInstruction_sbc_al_r3_r9_r3_LSL_13[] = {
  0x69, 0xeb, 0x43, 0x33 // sbc al r3 r9 r3 LSL 13
};
const byte kInstruction_sbc_al_r10_r2_r13_LSL_7[] = {
  0x62, 0xeb, 0xcd, 0x1a // sbc al r10 r2 r13 LSL 7
};
const byte kInstruction_sbc_al_r1_r0_r9_LSL_22[] = {
  0x60, 0xeb, 0x89, 0x51 // sbc al r1 r0 r9 LSL 22
};
const byte kInstruction_sbc_al_r8_r3_r9_ROR_24[] = {
  0x63, 0xeb, 0x39, 0x68 // sbc al r8 r3 r9 ROR 24
};
const byte kInstruction_sbc_al_r9_r13_r8_LSL_25[] = {
  0x6d, 0xeb, 0x48, 0x69 // sbc al r9 r13 r8 LSL 25
};
const byte kInstruction_sbc_al_r7_r2_r13_ROR_16[] = {
  0x62, 0xeb, 0x3d, 0x47 // sbc al r7 r2 r13 ROR 16
};
const byte kInstruction_sbc_al_r5_r6_r3_LSL_3[] = {
  0x66, 0xeb, 0xc3, 0x05 // sbc al r5 r6 r3 LSL 3
};
const byte kInstruction_sbc_al_r5_r6_r10_LSL_15[] = {
  0x66, 0xeb, 0xca, 0x35 // sbc al r5 r6 r10 LSL 15
};
const byte kInstruction_sbc_al_r6_r8_r12_LSL_13[] = {
  0x68, 0xeb, 0x4c, 0x36 // sbc al r6 r8 r12 LSL 13
};
const byte kInstruction_sbc_al_r1_r9_r11_ROR_7[] = {
  0x69, 0xeb, 0xfb, 0x11 // sbc al r1 r9 r11 ROR 7
};
const byte kInstruction_sbc_al_r0_r3_r7_LSL_12[] = {
  0x63, 0xeb, 0x07, 0x30 // sbc al r0 r3 r7 LSL 12
};
const byte kInstruction_sbc_al_r8_r10_r2_ROR_6[] = {
  0x6a, 0xeb, 0xb2, 0x18 // sbc al r8 r10 r2 ROR 6
};
const byte kInstruction_sbc_al_r2_r11_r5_LSL_10[] = {
  0x6b, 0xeb, 0x85, 0x22 // sbc al r2 r11 r5 LSL 10
};
const byte kInstruction_sbc_al_r13_r5_r4_LSL_15[] = {
  0x65, 0xeb, 0xc4, 0x3d // sbc al r13 r5 r4 LSL 15
};
const byte kInstruction_sbc_al_r6_r1_r12_LSL_27[] = {
  0x61, 0xeb, 0xcc, 0x66 // sbc al r6 r1 r12 LSL 27
};
const byte kInstruction_sbc_al_r14_r3_r5_ROR_19[] = {
  0x63, 0xeb, 0xf5, 0x4e // sbc al r14 r3 r5 ROR 19
};
const byte kInstruction_sbc_al_r14_r0_r13_LSL_12[] = {
  0x60, 0xeb, 0x0d, 0x3e // sbc al r14 r0 r13 LSL 12
};
const byte kInstruction_sbc_al_r11_r2_r8_ROR_15[] = {
  0x62, 0xeb, 0xf8, 0x3b // sbc al r11 r2 r8 ROR 15
};
const byte kInstruction_sbc_al_r0_r1_r3_ROR_1[] = {
  0x61, 0xeb, 0x73, 0x00 // sbc al r0 r1 r3 ROR 1
};
const byte kInstruction_sbc_al_r13_r11_r11_ROR_31[] = {
  0x6b, 0xeb, 0xfb, 0x7d // sbc al r13 r11 r11 ROR 31
};
const byte kInstruction_sbc_al_r1_r4_r4_LSL_20[] = {
  0x64, 0xeb, 0x04, 0x51 // sbc al r1 r4 r4 LSL 20
};
const byte kInstruction_sbc_al_r2_r7_r6_ROR_7[] = {
  0x67, 0xeb, 0xf6, 0x12 // sbc al r2 r7 r6 ROR 7
};
const byte kInstruction_sbc_al_r0_r3_r11_ROR_21[] = {
  0x63, 0xeb, 0x7b, 0x50 // sbc al r0 r3 r11 ROR 21
};
const byte kInstruction_sbc_al_r14_r9_r6_LSL_20[] = {
  0x69, 0xeb, 0x06, 0x5e // sbc al r14 r9 r6 LSL 20
};
const byte kInstruction_sbc_al_r11_r2_r14_ROR_1[] = {
  0x62, 0xeb, 0x7e, 0x0b // sbc al r11 r2 r14 ROR 1
};
const byte kInstruction_sbc_al_r13_r10_r8_ROR_22[] = {
  0x6a, 0xeb, 0xb8, 0x5d // sbc al r13 r10 r8 ROR 22
};
const byte kInstruction_sbc_al_r11_r2_r2_LSL_27[] = {
  0x62, 0xeb, 0xc2, 0x6b // sbc al r11 r2 r2 LSL 27
};
const byte kInstruction_sbc_al_r3_r2_r14_LSL_6[] = {
  0x62, 0xeb, 0x8e, 0x13 // sbc al r3 r2 r14 LSL 6
};
const byte kInstruction_sbc_al_r8_r3_r0_LSL_20[] = {
  0x63, 0xeb, 0x00, 0x58 // sbc al r8 r3 r0 LSL 20
};
const byte kInstruction_sbc_al_r8_r14_r11_ROR_19[] = {
  0x6e, 0xeb, 0xfb, 0x48 // sbc al r8 r14 r11 ROR 19
};
const byte kInstruction_sbc_al_r7_r14_r0_ROR_8[] = {
  0x6e, 0xeb, 0x30, 0x27 // sbc al r7 r14 r0 ROR 8
};
const byte kInstruction_sbc_al_r6_r6_r3_ROR_13[] = {
  0x66, 0xeb, 0x73, 0x36 // sbc al r6 r6 r3 ROR 13
};
const byte kInstruction_sbc_al_r1_r9_r3_LSL_10[] = {
  0x69, 0xeb, 0x83, 0x21 // sbc al r1 r9 r3 LSL 10
};
const byte kInstruction_sbc_al_r14_r12_r14_ROR_13[] = {
  0x6c, 0xeb, 0x7e, 0x3e // sbc al r14 r12 r14 ROR 13
};
const byte kInstruction_sbc_al_r8_r5_r13_LSL_19[] = {
  0x65, 0xeb, 0xcd, 0x48 // sbc al r8 r5 r13 LSL 19
};
const byte kInstruction_sbc_al_r6_r10_r10_ROR_3[] = {
  0x6a, 0xeb, 0xfa, 0x06 // sbc al r6 r10 r10 ROR 3
};
const byte kInstruction_sbc_al_r9_r5_r1_ROR_19[] = {
  0x65, 0xeb, 0xf1, 0x49 // sbc al r9 r5 r1 ROR 19
};
const byte kInstruction_sbc_al_r10_r8_r1_LSL_12[] = {
  0x68, 0xeb, 0x01, 0x3a // sbc al r10 r8 r1 LSL 12
};
const byte kInstruction_sbc_al_r3_r0_r6_ROR_31[] = {
  0x60, 0xeb, 0xf6, 0x73 // sbc al r3 r0 r6 ROR 31
};
const byte kInstruction_sbc_al_r6_r6_r5_ROR_1[] = {
  0x66, 0xeb, 0x75, 0x06 // sbc al r6 r6 r5 ROR 1
};
const byte kInstruction_sbc_al_r3_r0_r0_LSL_18[] = {
  0x60, 0xeb, 0x80, 0x43 // sbc al r3 r0 r0 LSL 18
};
const byte kInstruction_sbc_al_r14_r12_r1_LSL_11[] = {
  0x6c, 0xeb, 0xc1, 0x2e // sbc al r14 r12 r1 LSL 11
};
const byte kInstruction_sbc_al_r4_r13_r1_ROR_17[] = {
  0x6d, 0xeb, 0x71, 0x44 // sbc al r4 r13 r1 ROR 17
};
const byte kInstruction_sbc_al_r1_r13_r0_ROR_10[] = {
  0x6d, 0xeb, 0xb0, 0x21 // sbc al r1 r13 r0 ROR 10
};
const byte kInstruction_sbc_al_r8_r0_r0_LSL_11[] = {
  0x60, 0xeb, 0xc0, 0x28 // sbc al r8 r0 r0 LSL 11
};
const byte kInstruction_sbc_al_r3_r3_r10_ROR_18[] = {
  0x63, 0xeb, 0xba, 0x43 // sbc al r3 r3 r10 ROR 18
};
const byte kInstruction_sbc_al_r12_r8_r9_LSL_7[] = {
  0x68, 0xeb, 0xc9, 0x1c // sbc al r12 r8 r9 LSL 7
};
const byte kInstruction_sbc_al_r3_r3_r11_ROR_10[] = {
  0x63, 0xeb, 0xbb, 0x23 // sbc al r3 r3 r11 ROR 10
};
const byte kInstruction_sbc_al_r3_r14_r6_ROR_5[] = {
  0x6e, 0xeb, 0x76, 0x13 // sbc al r3 r14 r6 ROR 5
};
const byte kInstruction_sbc_al_r7_r0_r12_ROR_7[] = {
  0x60, 0xeb, 0xfc, 0x17 // sbc al r7 r0 r12 ROR 7
};
const byte kInstruction_sbc_al_r12_r2_r8_LSL_13[] = {
  0x62, 0xeb, 0x48, 0x3c // sbc al r12 r2 r8 LSL 13
};
const byte kInstruction_sbc_al_r10_r1_r0_ROR_8[] = {
  0x61, 0xeb, 0x30, 0x2a // sbc al r10 r1 r0 ROR 8
};
const byte kInstruction_sbc_al_r6_r12_r6_LSL_30[] = {
  0x6c, 0xeb, 0x86, 0x76 // sbc al r6 r12 r6 LSL 30
};
const byte kInstruction_sbc_al_r6_r3_r7_ROR_11[] = {
  0x63, 0xeb, 0xf7, 0x26 // sbc al r6 r3 r7 ROR 11
};
const byte kInstruction_sbc_al_r5_r12_r7_ROR_28[] = {
  0x6c, 0xeb, 0x37, 0x75 // sbc al r5 r12 r7 ROR 28
};
const byte kInstruction_sbc_al_r4_r12_r10_LSL_6[] = {
  0x6c, 0xeb, 0x8a, 0x14 // sbc al r4 r12 r10 LSL 6
};
const byte kInstruction_sbc_al_r11_r5_r1_ROR_3[] = {
  0x65, 0xeb, 0xf1, 0x0b // sbc al r11 r5 r1 ROR 3
};
const byte kInstruction_sbc_al_r9_r3_r0_ROR_26[] = {
  0x63, 0xeb, 0xb0, 0x69 // sbc al r9 r3 r0 ROR 26
};
const byte kInstruction_sbc_al_r8_r1_r10_LSL_13[] = {
  0x61, 0xeb, 0x4a, 0x38 // sbc al r8 r1 r10 LSL 13
};
const byte kInstruction_sbc_al_r14_r13_r14_ROR_20[] = {
  0x6d, 0xeb, 0x3e, 0x5e // sbc al r14 r13 r14 ROR 20
};
const byte kInstruction_sbc_al_r2_r3_r8_LSL_7[] = {
  0x63, 0xeb, 0xc8, 0x12 // sbc al r2 r3 r8 LSL 7
};
const byte kInstruction_sbc_al_r0_r11_r10_ROR_4[] = {
  0x6b, 0xeb, 0x3a, 0x10 // sbc al r0 r11 r10 ROR 4
};
const byte kInstruction_sbc_al_r1_r6_r9_LSL_27[] = {
  0x66, 0xeb, 0xc9, 0x61 // sbc al r1 r6 r9 LSL 27
};
const byte kInstruction_sbc_al_r5_r2_r4_ROR_10[] = {
  0x62, 0xeb, 0xb4, 0x25 // sbc al r5 r2 r4 ROR 10
};
const byte kInstruction_sbc_al_r13_r8_r9_LSL_20[] = {
  0x68, 0xeb, 0x09, 0x5d // sbc al r13 r8 r9 LSL 20
};
const byte kInstruction_sbc_al_r11_r7_r0_LSL_20[] = {
  0x67, 0xeb, 0x00, 0x5b // sbc al r11 r7 r0 LSL 20
};
const byte kInstruction_sbc_al_r2_r9_r1_LSL_30[] = {
  0x69, 0xeb, 0x81, 0x72 // sbc al r2 r9 r1 LSL 30
};
const byte kInstruction_sbc_al_r5_r0_r5_ROR_24[] = {
  0x60, 0xeb, 0x35, 0x65 // sbc al r5 r0 r5 ROR 24
};
const byte kInstruction_sbc_al_r7_r4_r10_LSL_17[] = {
  0x64, 0xeb, 0x4a, 0x47 // sbc al r7 r4 r10 LSL 17
};
const byte kInstruction_sbc_al_r11_r3_r7_ROR_19[] = {
  0x63, 0xeb, 0xf7, 0x4b // sbc al r11 r3 r7 ROR 19
};
const byte kInstruction_sbc_al_r8_r2_r6_ROR_1[] = {
  0x62, 0xeb, 0x76, 0x08 // sbc al r8 r2 r6 ROR 1
};
const byte kInstruction_sbc_al_r5_r1_r8_ROR_25[] = {
  0x61, 0xeb, 0x78, 0x65 // sbc al r5 r1 r8 ROR 25
};
const byte kInstruction_sbc_al_r1_r4_r12_LSL_28[] = {
  0x64, 0xeb, 0x0c, 0x71 // sbc al r1 r4 r12 LSL 28
};
const byte kInstruction_sbc_al_r12_r1_r4_LSL_14[] = {
  0x61, 0xeb, 0x84, 0x3c // sbc al r12 r1 r4 LSL 14
};
const byte kInstruction_sbc_al_r9_r12_r13_LSL_25[] = {
  0x6c, 0xeb, 0x4d, 0x69 // sbc al r9 r12 r13 LSL 25
};
const byte kInstruction_sbc_al_r11_r14_r5_ROR_12[] = {
  0x6e, 0xeb, 0x35, 0x3b // sbc al r11 r14 r5 ROR 12
};
const byte kInstruction_sbc_al_r3_r8_r13_LSL_4[] = {
  0x68, 0xeb, 0x0d, 0x13 // sbc al r3 r8 r13 LSL 4
};
const byte kInstruction_sbc_al_r9_r14_r10_ROR_12[] = {
  0x6e, 0xeb, 0x3a, 0x39 // sbc al r9 r14 r10 ROR 12
};
const byte kInstruction_sbc_al_r0_r13_r1_ROR_30[] = {
  0x6d, 0xeb, 0xb1, 0x70 // sbc al r0 r13 r1 ROR 30
};
const byte kInstruction_sbc_al_r11_r9_r9_ROR_23[] = {
  0x69, 0xeb, 0xf9, 0x5b // sbc al r11 r9 r9 ROR 23
};
const byte kInstruction_sbc_al_r5_r2_r8_ROR_6[] = {
  0x62, 0xeb, 0xb8, 0x15 // sbc al r5 r2 r8 ROR 6
};
const byte kInstruction_sbc_al_r8_r14_r10_ROR_23[] = {
  0x6e, 0xeb, 0xfa, 0x58 // sbc al r8 r14 r10 ROR 23
};
const byte kInstruction_sbc_al_r14_r12_r2_LSL_26[] = {
  0x6c, 0xeb, 0x82, 0x6e // sbc al r14 r12 r2 LSL 26
};
const byte kInstruction_sbc_al_r2_r9_r10_LSL_12[] = {
  0x69, 0xeb, 0x0a, 0x32 // sbc al r2 r9 r10 LSL 12
};
const byte kInstruction_sbc_al_r3_r1_r11_LSL_17[] = {
  0x61, 0xeb, 0x4b, 0x43 // sbc al r3 r1 r11 LSL 17
};
const byte kInstruction_sbc_al_r3_r8_r10_LSL_23[] = {
  0x68, 0xeb, 0xca, 0x53 // sbc al r3 r8 r10 LSL 23
};
const byte kInstruction_sbc_al_r3_r6_r4_ROR_31[] = {
  0x66, 0xeb, 0xf4, 0x73 // sbc al r3 r6 r4 ROR 31
};
const byte kInstruction_sbc_al_r3_r5_r10_LSL_22[] = {
  0x65, 0xeb, 0x8a, 0x53 // sbc al r3 r5 r10 LSL 22
};
const byte kInstruction_sbc_al_r0_r3_r10_ROR_1[] = {
  0x63, 0xeb, 0x7a, 0x00 // sbc al r0 r3 r10 ROR 1
};
const byte kInstruction_sbc_al_r5_r9_r7_ROR_9[] = {
  0x69, 0xeb, 0x77, 0x25 // sbc al r5 r9 r7 ROR 9
};
const byte kInstruction_sbc_al_r11_r2_r2_LSL_24[] = {
  0x62, 0xeb, 0x02, 0x6b // sbc al r11 r2 r2 LSL 24
};
const byte kInstruction_sbc_al_r10_r11_r7_LSL_29[] = {
  0x6b, 0xeb, 0x47, 0x7a // sbc al r10 r11 r7 LSL 29
};
const byte kInstruction_sbc_al_r5_r4_r10_ROR_26[] = {
  0x64, 0xeb, 0xba, 0x65 // sbc al r5 r4 r10 ROR 26
};
const byte kInstruction_sbc_al_r8_r8_r7_LSL_20[] = {
  0x68, 0xeb, 0x07, 0x58 // sbc al r8 r8 r7 LSL 20
};
const byte kInstruction_sbc_al_r12_r6_r5_ROR_20[] = {
  0x66, 0xeb, 0x35, 0x5c // sbc al r12 r6 r5 ROR 20
};
const byte kInstruction_sbc_al_r9_r4_r7_LSL_21[] = {
  0x64, 0xeb, 0x47, 0x59 // sbc al r9 r4 r7 LSL 21
};
const byte kInstruction_sbc_al_r8_r2_r7_LSL_4[] = {
  0x62, 0xeb, 0x07, 0x18 // sbc al r8 r2 r7 LSL 4
};
const byte kInstruction_sbc_al_r9_r14_r12_LSL_8[] = {
  0x6e, 0xeb, 0x0c, 0x29 // sbc al r9 r14 r12 LSL 8
};
const byte kInstruction_sbc_al_r1_r12_r8_ROR_25[] = {
  0x6c, 0xeb, 0x78, 0x61 // sbc al r1 r12 r8 ROR 25
};
const byte kInstruction_sbc_al_r4_r1_r4_ROR_26[] = {
  0x61, 0xeb, 0xb4, 0x64 // sbc al r4 r1 r4 ROR 26
};
const byte kInstruction_sbc_al_r12_r6_r14_ROR_22[] = {
  0x66, 0xeb, 0xbe, 0x5c // sbc al r12 r6 r14 ROR 22
};
const byte kInstruction_sbc_al_r2_r6_r9_LSL_17[] = {
  0x66, 0xeb, 0x49, 0x42 // sbc al r2 r6 r9 LSL 17
};
const byte kInstruction_sbc_al_r8_r8_r1_ROR_15[] = {
  0x68, 0xeb, 0xf1, 0x38 // sbc al r8 r8 r1 ROR 15
};
const byte kInstruction_sbc_al_r13_r10_r8_ROR_27[] = {
  0x6a, 0xeb, 0xf8, 0x6d // sbc al r13 r10 r8 ROR 27
};
const byte kInstruction_sbc_al_r1_r10_r10_LSL_27[] = {
  0x6a, 0xeb, 0xca, 0x61 // sbc al r1 r10 r10 LSL 27
};
const byte kInstruction_sbc_al_r7_r1_r11_ROR_26[] = {
  0x61, 0xeb, 0xbb, 0x67 // sbc al r7 r1 r11 ROR 26
};
const byte kInstruction_sbc_al_r13_r14_r11_ROR_29[] = {
  0x6e, 0xeb, 0x7b, 0x7d // sbc al r13 r14 r11 ROR 29
};
const byte kInstruction_sbc_al_r5_r3_r14_ROR_7[] = {
  0x63, 0xeb, 0xfe, 0x15 // sbc al r5 r3 r14 ROR 7
};
const byte kInstruction_sbc_al_r2_r12_r9_LSL_22[] = {
  0x6c, 0xeb, 0x89, 0x52 // sbc al r2 r12 r9 LSL 22
};
const byte kInstruction_sbc_al_r4_r2_r9_LSL_12[] = {
  0x62, 0xeb, 0x09, 0x34 // sbc al r4 r2 r9 LSL 12
};
const byte kInstruction_sbc_al_r6_r7_r5_LSL_8[] = {
  0x67, 0xeb, 0x05, 0x26 // sbc al r6 r7 r5 LSL 8
};
const byte kInstruction_sbc_al_r14_r11_r6_LSL_10[] = {
  0x6b, 0xeb, 0x86, 0x2e // sbc al r14 r11 r6 LSL 10
};
const byte kInstruction_sbc_al_r11_r10_r7_ROR_10[] = {
  0x6a, 0xeb, 0xb7, 0x2b // sbc al r11 r10 r7 ROR 10
};
const byte kInstruction_sbc_al_r9_r11_r5_ROR_8[] = {
  0x6b, 0xeb, 0x35, 0x29 // sbc al r9 r11 r5 ROR 8
};
const byte kInstruction_sbc_al_r13_r12_r0_ROR_1[] = {
  0x6c, 0xeb, 0x70, 0x0d // sbc al r13 r12 r0 ROR 1
};
const byte kInstruction_sbc_al_r7_r9_r3_ROR_1[] = {
  0x69, 0xeb, 0x73, 0x07 // sbc al r7 r9 r3 ROR 1
};
const byte kInstruction_sbc_al_r10_r2_r13_LSL_17[] = {
  0x62, 0xeb, 0x4d, 0x4a // sbc al r10 r2 r13 LSL 17
};
const byte kInstruction_sbc_al_r10_r6_r6_LSL_16[] = {
  0x66, 0xeb, 0x06, 0x4a // sbc al r10 r6 r6 LSL 16
};
const byte kInstruction_sbc_al_r5_r8_r9_ROR_25[] = {
  0x68, 0xeb, 0x79, 0x65 // sbc al r5 r8 r9 ROR 25
};
const byte kInstruction_sbc_al_r14_r13_r2_LSL_23[] = {
  0x6d, 0xeb, 0xc2, 0x5e // sbc al r14 r13 r2 LSL 23
};
const byte kInstruction_sbc_al_r5_r13_r6_ROR_13[] = {
  0x6d, 0xeb, 0x76, 0x35 // sbc al r5 r13 r6 ROR 13
};
const byte kInstruction_sbc_al_r6_r14_r5_LSL_3[] = {
  0x6e, 0xeb, 0xc5, 0x06 // sbc al r6 r14 r5 LSL 3
};
const byte kInstruction_sbc_al_r11_r8_r14_ROR_2[] = {
  0x68, 0xeb, 0xbe, 0x0b // sbc al r11 r8 r14 ROR 2
};
const byte kInstruction_sbc_al_r3_r11_r13_ROR_25[] = {
  0x6b, 0xeb, 0x7d, 0x63 // sbc al r3 r11 r13 ROR 25
};
const byte kInstruction_sbc_al_r2_r1_r6_LSL_3[] = {
  0x61, 0xeb, 0xc6, 0x02 // sbc al r2 r1 r6 LSL 3
};
const byte kInstruction_sbc_al_r1_r7_r3_ROR_30[] = {
  0x67, 0xeb, 0xb3, 0x71 // sbc al r1 r7 r3 ROR 30
};
const TestResult kReferencesbc[] = {
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r4_r7_LSL_7),
    kInstruction_sbc_al_r12_r4_r7_LSL_7,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r8_r10_ROR_21),
    kInstruction_sbc_al_r7_r8_r10_ROR_21,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r5_r3_ROR_12),
    kInstruction_sbc_al_r5_r5_r3_ROR_12,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r13_r10_LSL_22),
    kInstruction_sbc_al_r14_r13_r10_LSL_22,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r10_r11_ROR_2),
    kInstruction_sbc_al_r9_r10_r11_ROR_2,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r11_r5_LSL_15),
    kInstruction_sbc_al_r14_r11_r5_LSL_15,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r2_r7_LSL_28),
    kInstruction_sbc_al_r2_r2_r7_LSL_28,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r11_r1_ROR_9),
    kInstruction_sbc_al_r2_r11_r1_ROR_9,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r2_r8_LSL_4),
    kInstruction_sbc_al_r11_r2_r8_LSL_4,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r13_r3_ROR_1),
    kInstruction_sbc_al_r6_r13_r3_ROR_1,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r2_r7_LSL_11),
    kInstruction_sbc_al_r13_r2_r7_LSL_11,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r9_r1_LSL_29),
    kInstruction_sbc_al_r9_r9_r1_LSL_29,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r12_r1_LSL_15),
    kInstruction_sbc_al_r2_r12_r1_LSL_15,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r2_r11_LSL_10),
    kInstruction_sbc_al_r0_r2_r11_LSL_10,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r12_r8_LSL_13),
    kInstruction_sbc_al_r11_r12_r8_LSL_13,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r1_r6_ROR_3),
    kInstruction_sbc_al_r3_r1_r6_ROR_3,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r9_r11_LSL_16),
    kInstruction_sbc_al_r5_r9_r11_LSL_16,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r0_r6_ROR_3),
    kInstruction_sbc_al_r2_r0_r6_ROR_3,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r10_r10_ROR_19),
    kInstruction_sbc_al_r7_r10_r10_ROR_19,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r12_r11_LSL_27),
    kInstruction_sbc_al_r14_r12_r11_LSL_27,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r13_r1_LSL_3),
    kInstruction_sbc_al_r2_r13_r1_LSL_3,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r3_r2_LSL_11),
    kInstruction_sbc_al_r5_r3_r2_LSL_11,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r3_r6_ROR_1),
    kInstruction_sbc_al_r10_r3_r6_ROR_1,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r14_r2_ROR_13),
    kInstruction_sbc_al_r6_r14_r2_ROR_13,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r8_r6_ROR_13),
    kInstruction_sbc_al_r9_r8_r6_ROR_13,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r5_r8_LSL_22),
    kInstruction_sbc_al_r12_r5_r8_LSL_22,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r8_r11_LSL_3),
    kInstruction_sbc_al_r11_r8_r11_LSL_3,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r9_r4_LSL_24),
    kInstruction_sbc_al_r0_r9_r4_LSL_24,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r2_r7_ROR_30),
    kInstruction_sbc_al_r2_r2_r7_ROR_30,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r3_r10_LSL_27),
    kInstruction_sbc_al_r9_r3_r10_LSL_27,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r4_r11_LSL_23),
    kInstruction_sbc_al_r10_r4_r11_LSL_23,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r5_r11_ROR_8),
    kInstruction_sbc_al_r12_r5_r11_ROR_8,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r6_r6_ROR_4),
    kInstruction_sbc_al_r6_r6_r6_ROR_4,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r5_r10_ROR_29),
    kInstruction_sbc_al_r5_r5_r10_ROR_29,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r12_r1_LSL_8),
    kInstruction_sbc_al_r12_r12_r1_LSL_8,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r3_r1_LSL_4),
    kInstruction_sbc_al_r5_r3_r1_LSL_4,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r11_r7_LSL_17),
    kInstruction_sbc_al_r4_r11_r7_LSL_17,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r8_r3_LSL_2),
    kInstruction_sbc_al_r12_r8_r3_LSL_2,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r11_r3_LSL_13),
    kInstruction_sbc_al_r2_r11_r3_LSL_13,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r11_r4_ROR_19),
    kInstruction_sbc_al_r11_r11_r4_ROR_19,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r1_r3_LSL_4),
    kInstruction_sbc_al_r5_r1_r3_LSL_4,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r5_r7_ROR_20),
    kInstruction_sbc_al_r2_r5_r7_ROR_20,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r8_r1_LSL_24),
    kInstruction_sbc_al_r8_r8_r1_LSL_24,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r1_r0_LSL_11),
    kInstruction_sbc_al_r7_r1_r0_LSL_11,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r5_r0_LSL_17),
    kInstruction_sbc_al_r10_r5_r0_LSL_17,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r13_r13_ROR_18),
    kInstruction_sbc_al_r14_r13_r13_ROR_18,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r3_r11_LSL_4),
    kInstruction_sbc_al_r8_r3_r11_LSL_4,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r11_r10_LSL_2),
    kInstruction_sbc_al_r1_r11_r10_LSL_2,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r2_r11_LSL_25),
    kInstruction_sbc_al_r0_r2_r11_LSL_25,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r1_r12_LSL_7),
    kInstruction_sbc_al_r0_r1_r12_LSL_7,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r0_r8_LSL_19),
    kInstruction_sbc_al_r5_r0_r8_LSL_19,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r5_r8_ROR_16),
    kInstruction_sbc_al_r1_r5_r8_ROR_16,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r11_r0_LSL_7),
    kInstruction_sbc_al_r5_r11_r0_LSL_7,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r5_r9_LSL_28),
    kInstruction_sbc_al_r4_r5_r9_LSL_28,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r6_r0_ROR_5),
    kInstruction_sbc_al_r2_r6_r0_ROR_5,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r13_r4_ROR_19),
    kInstruction_sbc_al_r8_r13_r4_ROR_19,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r11_r4_LSL_27),
    kInstruction_sbc_al_r10_r11_r4_LSL_27,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r8_r10_ROR_12),
    kInstruction_sbc_al_r2_r8_r10_ROR_12,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r11_r8_ROR_30),
    kInstruction_sbc_al_r8_r11_r8_ROR_30,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r12_r14_LSL_21),
    kInstruction_sbc_al_r7_r12_r14_LSL_21,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r7_r14_LSL_18),
    kInstruction_sbc_al_r1_r7_r14_LSL_18,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r2_r11_ROR_26),
    kInstruction_sbc_al_r1_r2_r11_ROR_26,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r10_r0_ROR_10),
    kInstruction_sbc_al_r12_r10_r0_ROR_10,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r4_r10_ROR_22),
    kInstruction_sbc_al_r4_r4_r10_ROR_22,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r10_r11_LSL_25),
    kInstruction_sbc_al_r10_r10_r11_LSL_25,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r11_r12_LSL_20),
    kInstruction_sbc_al_r5_r11_r12_LSL_20,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r14_r7_LSL_26),
    kInstruction_sbc_al_r6_r14_r7_LSL_26,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r3_r3_LSL_10),
    kInstruction_sbc_al_r10_r3_r3_LSL_10,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r3_r5_LSL_24),
    kInstruction_sbc_al_r11_r3_r5_LSL_24,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r5_r10_ROR_23),
    kInstruction_sbc_al_r9_r5_r10_ROR_23,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r6_r5_ROR_28),
    kInstruction_sbc_al_r4_r6_r5_ROR_28,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r10_r4_ROR_26),
    kInstruction_sbc_al_r9_r10_r4_ROR_26,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r0_r9_LSL_2),
    kInstruction_sbc_al_r9_r0_r9_LSL_2,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r12_r8_LSL_23),
    kInstruction_sbc_al_r4_r12_r8_LSL_23,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r9_r11_LSL_18),
    kInstruction_sbc_al_r7_r9_r11_LSL_18,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r2_r3_LSL_19),
    kInstruction_sbc_al_r5_r2_r3_LSL_19,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r5_r1_ROR_10),
    kInstruction_sbc_al_r5_r5_r1_ROR_10,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r0_r7_ROR_27),
    kInstruction_sbc_al_r3_r0_r7_ROR_27,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r12_r8_ROR_14),
    kInstruction_sbc_al_r8_r12_r8_ROR_14,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r8_r2_LSL_25),
    kInstruction_sbc_al_r3_r8_r2_LSL_25,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r5_r8_LSL_24),
    kInstruction_sbc_al_r8_r5_r8_LSL_24,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r2_r9_LSL_23),
    kInstruction_sbc_al_r10_r2_r9_LSL_23,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r11_r3_ROR_25),
    kInstruction_sbc_al_r13_r11_r3_ROR_25,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r13_r2_ROR_1),
    kInstruction_sbc_al_r2_r13_r2_ROR_1,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r7_r7_ROR_18),
    kInstruction_sbc_al_r9_r7_r7_ROR_18,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r13_r4_ROR_15),
    kInstruction_sbc_al_r13_r13_r4_ROR_15,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r2_r0_LSL_1),
    kInstruction_sbc_al_r1_r2_r0_LSL_1,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r14_r1_LSL_7),
    kInstruction_sbc_al_r0_r14_r1_LSL_7,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r2_r3_LSL_18),
    kInstruction_sbc_al_r2_r2_r3_LSL_18,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r12_r10_ROR_22),
    kInstruction_sbc_al_r12_r12_r10_ROR_22,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r10_r2_ROR_13),
    kInstruction_sbc_al_r12_r10_r2_ROR_13,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r3_r11_LSL_23),
    kInstruction_sbc_al_r7_r3_r11_LSL_23,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r7_r14_LSL_10),
    kInstruction_sbc_al_r4_r7_r14_LSL_10,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r7_r5_ROR_27),
    kInstruction_sbc_al_r3_r7_r5_ROR_27,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r11_r5_ROR_24),
    kInstruction_sbc_al_r5_r11_r5_ROR_24,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r0_r6_ROR_29),
    kInstruction_sbc_al_r12_r0_r6_ROR_29,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r3_r8_LSL_26),
    kInstruction_sbc_al_r14_r3_r8_LSL_26,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r10_r3_LSL_10),
    kInstruction_sbc_al_r12_r10_r3_LSL_10,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r8_r6_ROR_16),
    kInstruction_sbc_al_r3_r8_r6_ROR_16,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r1_r1_LSL_23),
    kInstruction_sbc_al_r14_r1_r1_LSL_23,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r1_r0_LSL_18),
    kInstruction_sbc_al_r14_r1_r0_LSL_18,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r1_r8_LSL_29),
    kInstruction_sbc_al_r7_r1_r8_LSL_29,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r12_r1_ROR_22),
    kInstruction_sbc_al_r8_r12_r1_ROR_22,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r12_r10_ROR_10),
    kInstruction_sbc_al_r8_r12_r10_ROR_10,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r14_r3_ROR_7),
    kInstruction_sbc_al_r1_r14_r3_ROR_7,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r4_r3_LSL_20),
    kInstruction_sbc_al_r3_r4_r3_LSL_20,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r13_r0_LSL_7),
    kInstruction_sbc_al_r2_r13_r0_LSL_7,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r0_r9_ROR_20),
    kInstruction_sbc_al_r13_r0_r9_ROR_20,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r4_r14_ROR_5),
    kInstruction_sbc_al_r6_r4_r14_ROR_5,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r8_r9_ROR_3),
    kInstruction_sbc_al_r12_r8_r9_ROR_3,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r11_r2_LSL_19),
    kInstruction_sbc_al_r0_r11_r2_LSL_19,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r3_r3_LSL_8),
    kInstruction_sbc_al_r2_r3_r3_LSL_8,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r1_r1_ROR_26),
    kInstruction_sbc_al_r5_r1_r1_ROR_26,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r4_r13_ROR_31),
    kInstruction_sbc_al_r4_r4_r13_ROR_31,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r6_r8_ROR_11),
    kInstruction_sbc_al_r4_r6_r8_ROR_11,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r10_r13_LSL_28),
    kInstruction_sbc_al_r4_r10_r13_LSL_28,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r8_r5_LSL_19),
    kInstruction_sbc_al_r0_r8_r5_LSL_19,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r0_r7_ROR_10),
    kInstruction_sbc_al_r14_r0_r7_ROR_10,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r10_r9_ROR_13),
    kInstruction_sbc_al_r9_r10_r9_ROR_13,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r1_r7_LSL_31),
    kInstruction_sbc_al_r5_r1_r7_LSL_31,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r4_r12_ROR_8),
    kInstruction_sbc_al_r8_r4_r12_ROR_8,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r13_r0_LSL_4),
    kInstruction_sbc_al_r8_r13_r0_LSL_4,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r4_r10_LSL_19),
    kInstruction_sbc_al_r10_r4_r10_LSL_19,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r2_r3_LSL_5),
    kInstruction_sbc_al_r5_r2_r3_LSL_5,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r1_r2_LSL_17),
    kInstruction_sbc_al_r1_r1_r2_LSL_17,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r2_r13_ROR_13),
    kInstruction_sbc_al_r9_r2_r13_ROR_13,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r5_r5_ROR_8),
    kInstruction_sbc_al_r2_r5_r5_ROR_8,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r11_r10_ROR_31),
    kInstruction_sbc_al_r11_r11_r10_ROR_31,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r14_r13_LSL_23),
    kInstruction_sbc_al_r13_r14_r13_LSL_23,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r0_r3_ROR_6),
    kInstruction_sbc_al_r9_r0_r3_ROR_6,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r10_r11_LSL_9),
    kInstruction_sbc_al_r10_r10_r11_LSL_9,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r10_r11_ROR_31),
    kInstruction_sbc_al_r13_r10_r11_ROR_31,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r8_r10_LSL_23),
    kInstruction_sbc_al_r8_r8_r10_LSL_23,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r13_r10_ROR_27),
    kInstruction_sbc_al_r13_r13_r10_ROR_27,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r4_r7_LSL_19),
    kInstruction_sbc_al_r6_r4_r7_LSL_19,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r1_r7_LSL_23),
    kInstruction_sbc_al_r6_r1_r7_LSL_23,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r13_r9_ROR_2),
    kInstruction_sbc_al_r11_r13_r9_ROR_2,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r13_r8_LSL_11),
    kInstruction_sbc_al_r14_r13_r8_LSL_11,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r11_r8_ROR_11),
    kInstruction_sbc_al_r10_r11_r8_ROR_11,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r5_r1_ROR_15),
    kInstruction_sbc_al_r5_r5_r1_ROR_15,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r3_r0_LSL_14),
    kInstruction_sbc_al_r1_r3_r0_LSL_14,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r4_r0_ROR_29),
    kInstruction_sbc_al_r11_r4_r0_ROR_29,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r11_r10_ROR_25),
    kInstruction_sbc_al_r6_r11_r10_ROR_25,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r3_r9_ROR_15),
    kInstruction_sbc_al_r8_r3_r9_ROR_15,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r12_r14_LSL_23),
    kInstruction_sbc_al_r3_r12_r14_LSL_23,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r14_r6_ROR_23),
    kInstruction_sbc_al_r14_r14_r6_ROR_23,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r8_r8_ROR_25),
    kInstruction_sbc_al_r6_r8_r8_ROR_25,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r5_r2_LSL_17),
    kInstruction_sbc_al_r5_r5_r2_LSL_17,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r4_r6_ROR_13),
    kInstruction_sbc_al_r13_r4_r6_ROR_13,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r9_r0_LSL_25),
    kInstruction_sbc_al_r10_r9_r0_LSL_25,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r2_r5_ROR_15),
    kInstruction_sbc_al_r11_r2_r5_ROR_15,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r13_r4_LSL_8),
    kInstruction_sbc_al_r4_r13_r4_LSL_8,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r6_r5_LSL_31),
    kInstruction_sbc_al_r13_r6_r5_LSL_31,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r5_r6_ROR_25),
    kInstruction_sbc_al_r3_r5_r6_ROR_25,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r7_r12_ROR_12),
    kInstruction_sbc_al_r7_r7_r12_ROR_12,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r10_r6_ROR_18),
    kInstruction_sbc_al_r6_r10_r6_ROR_18,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r14_r14_LSL_30),
    kInstruction_sbc_al_r8_r14_r14_LSL_30,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r0_r2_LSL_4),
    kInstruction_sbc_al_r0_r0_r2_LSL_4,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r2_r3_ROR_10),
    kInstruction_sbc_al_r11_r2_r3_ROR_10,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r6_r14_ROR_29),
    kInstruction_sbc_al_r2_r6_r14_ROR_29,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r5_r11_ROR_22),
    kInstruction_sbc_al_r4_r5_r11_ROR_22,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r5_r1_LSL_8),
    kInstruction_sbc_al_r13_r5_r1_LSL_8,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r3_r0_ROR_25),
    kInstruction_sbc_al_r9_r3_r0_ROR_25,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r0_r14_LSL_11),
    kInstruction_sbc_al_r10_r0_r14_LSL_11,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r13_r13_ROR_6),
    kInstruction_sbc_al_r8_r13_r13_ROR_6,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r7_r14_LSL_10),
    kInstruction_sbc_al_r10_r7_r14_LSL_10,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r6_r12_ROR_31),
    kInstruction_sbc_al_r9_r6_r12_ROR_31,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r5_r0_ROR_1),
    kInstruction_sbc_al_r9_r5_r0_ROR_1,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r10_r12_LSL_11),
    kInstruction_sbc_al_r0_r10_r12_LSL_11,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r0_r8_ROR_15),
    kInstruction_sbc_al_r8_r0_r8_ROR_15,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r2_r1_LSL_21),
    kInstruction_sbc_al_r13_r2_r1_LSL_21,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r0_r9_LSL_29),
    kInstruction_sbc_al_r3_r0_r9_LSL_29,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r10_r11_LSL_17),
    kInstruction_sbc_al_r14_r10_r11_LSL_17,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r4_r0_LSL_17),
    kInstruction_sbc_al_r13_r4_r0_LSL_17,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r3_r4_LSL_6),
    kInstruction_sbc_al_r0_r3_r4_LSL_6,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r9_r2_LSL_21),
    kInstruction_sbc_al_r13_r9_r2_LSL_21,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r5_r13_LSL_23),
    kInstruction_sbc_al_r13_r5_r13_LSL_23,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r10_r2_LSL_8),
    kInstruction_sbc_al_r14_r10_r2_LSL_8,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r11_r12_LSL_13),
    kInstruction_sbc_al_r12_r11_r12_LSL_13,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r2_r12_ROR_23),
    kInstruction_sbc_al_r10_r2_r12_ROR_23,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r5_r8_ROR_28),
    kInstruction_sbc_al_r5_r5_r8_ROR_28,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r14_r12_ROR_19),
    kInstruction_sbc_al_r0_r14_r12_ROR_19,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r13_r11_LSL_24),
    kInstruction_sbc_al_r8_r13_r11_LSL_24,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r5_r3_ROR_30),
    kInstruction_sbc_al_r9_r5_r3_ROR_30,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r10_r7_ROR_22),
    kInstruction_sbc_al_r9_r10_r7_ROR_22,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r3_r10_LSL_18),
    kInstruction_sbc_al_r10_r3_r10_LSL_18,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r3_r14_ROR_22),
    kInstruction_sbc_al_r7_r3_r14_ROR_22,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r4_r4_LSL_20),
    kInstruction_sbc_al_r11_r4_r4_LSL_20,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r13_r14_ROR_25),
    kInstruction_sbc_al_r7_r13_r14_ROR_25,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r10_r1_ROR_5),
    kInstruction_sbc_al_r10_r10_r1_ROR_5,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r12_r6_LSL_6),
    kInstruction_sbc_al_r4_r12_r6_LSL_6,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r6_r9_ROR_3),
    kInstruction_sbc_al_r3_r6_r9_ROR_3,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r3_r7_LSL_26),
    kInstruction_sbc_al_r14_r3_r7_LSL_26,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r8_r10_LSL_10),
    kInstruction_sbc_al_r0_r8_r10_LSL_10,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r10_r7_ROR_19),
    kInstruction_sbc_al_r13_r10_r7_ROR_19,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r1_r6_ROR_27),
    kInstruction_sbc_al_r14_r1_r6_ROR_27,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r5_r13_LSL_18),
    kInstruction_sbc_al_r0_r5_r13_LSL_18,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r9_r0_LSL_15),
    kInstruction_sbc_al_r10_r9_r0_LSL_15,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r8_r13_ROR_19),
    kInstruction_sbc_al_r12_r8_r13_ROR_19,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r0_r11_LSL_31),
    kInstruction_sbc_al_r8_r0_r11_LSL_31,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r14_r0_ROR_20),
    kInstruction_sbc_al_r8_r14_r0_ROR_20,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r7_r6_ROR_14),
    kInstruction_sbc_al_r8_r7_r6_ROR_14,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r9_r5_LSL_21),
    kInstruction_sbc_al_r10_r9_r5_LSL_21,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r8_r13_ROR_28),
    kInstruction_sbc_al_r9_r8_r13_ROR_28,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r12_r12_ROR_25),
    kInstruction_sbc_al_r12_r12_r12_ROR_25,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r11_r4_ROR_12),
    kInstruction_sbc_al_r5_r11_r4_ROR_12,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r7_r10_ROR_13),
    kInstruction_sbc_al_r1_r7_r10_ROR_13,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r12_r2_LSL_19),
    kInstruction_sbc_al_r14_r12_r2_LSL_19,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r5_r14_LSL_20),
    kInstruction_sbc_al_r0_r5_r14_LSL_20,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r4_r3_ROR_27),
    kInstruction_sbc_al_r12_r4_r3_ROR_27,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r3_r1_ROR_22),
    kInstruction_sbc_al_r9_r3_r1_ROR_22,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r12_r7_ROR_23),
    kInstruction_sbc_al_r2_r12_r7_ROR_23,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r4_r8_ROR_11),
    kInstruction_sbc_al_r10_r4_r8_ROR_11,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r0_r2_LSL_8),
    kInstruction_sbc_al_r6_r0_r2_LSL_8,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r3_r0_LSL_1),
    kInstruction_sbc_al_r10_r3_r0_LSL_1,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r6_r4_LSL_1),
    kInstruction_sbc_al_r6_r6_r4_LSL_1,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r12_r13_ROR_13),
    kInstruction_sbc_al_r13_r12_r13_ROR_13,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r9_r10_ROR_1),
    kInstruction_sbc_al_r0_r9_r10_ROR_1,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r13_r9_ROR_16),
    kInstruction_sbc_al_r9_r13_r9_ROR_16,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r6_r2_LSL_4),
    kInstruction_sbc_al_r0_r6_r2_LSL_4,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r2_r11_LSL_31),
    kInstruction_sbc_al_r9_r2_r11_LSL_31,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r12_r13_ROR_19),
    kInstruction_sbc_al_r12_r12_r13_ROR_19,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r14_r2_ROR_23),
    kInstruction_sbc_al_r7_r14_r2_ROR_23,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r1_r3_LSL_26),
    kInstruction_sbc_al_r7_r1_r3_LSL_26,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r6_r12_ROR_26),
    kInstruction_sbc_al_r13_r6_r12_ROR_26,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r14_r12_ROR_5),
    kInstruction_sbc_al_r10_r14_r12_ROR_5,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r9_r12_LSL_9),
    kInstruction_sbc_al_r5_r9_r12_LSL_9,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r7_r2_ROR_10),
    kInstruction_sbc_al_r2_r7_r2_ROR_10,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r12_r8_ROR_6),
    kInstruction_sbc_al_r12_r12_r8_ROR_6,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r13_r13_ROR_24),
    kInstruction_sbc_al_r1_r13_r13_ROR_24,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r10_r10_ROR_26),
    kInstruction_sbc_al_r6_r10_r10_ROR_26,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r9_r1_LSL_18),
    kInstruction_sbc_al_r13_r9_r1_LSL_18,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r1_r4_ROR_21),
    kInstruction_sbc_al_r6_r1_r4_ROR_21,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r3_r3_ROR_18),
    kInstruction_sbc_al_r0_r3_r3_ROR_18,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r9_r5_LSL_29),
    kInstruction_sbc_al_r1_r9_r5_LSL_29,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r8_r7_ROR_18),
    kInstruction_sbc_al_r11_r8_r7_ROR_18,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r3_r12_LSL_7),
    kInstruction_sbc_al_r2_r3_r12_LSL_7,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r3_r9_LSL_18),
    kInstruction_sbc_al_r8_r3_r9_LSL_18,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r12_r1_LSL_11),
    kInstruction_sbc_al_r8_r12_r1_LSL_11,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r9_r5_ROR_21),
    kInstruction_sbc_al_r14_r9_r5_ROR_21,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r6_r12_ROR_26),
    kInstruction_sbc_al_r0_r6_r12_ROR_26,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r6_r14_LSL_14),
    kInstruction_sbc_al_r3_r6_r14_LSL_14,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r0_r9_LSL_9),
    kInstruction_sbc_al_r11_r0_r9_LSL_9,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r13_r7_LSL_9),
    kInstruction_sbc_al_r8_r13_r7_LSL_9,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r1_r13_LSL_23),
    kInstruction_sbc_al_r3_r1_r13_LSL_23,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r13_r13_ROR_4),
    kInstruction_sbc_al_r12_r13_r13_ROR_4,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r14_r9_ROR_13),
    kInstruction_sbc_al_r10_r14_r9_ROR_13,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r5_r1_LSL_22),
    kInstruction_sbc_al_r14_r5_r1_LSL_22,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r8_r8_ROR_28),
    kInstruction_sbc_al_r11_r8_r8_ROR_28,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r8_r12_ROR_19),
    kInstruction_sbc_al_r0_r8_r12_ROR_19,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r3_r1_ROR_6),
    kInstruction_sbc_al_r11_r3_r1_ROR_6,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r7_r2_ROR_5),
    kInstruction_sbc_al_r2_r7_r2_ROR_5,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r14_r2_ROR_14),
    kInstruction_sbc_al_r11_r14_r2_ROR_14,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r13_r7_LSL_27),
    kInstruction_sbc_al_r9_r13_r7_LSL_27,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r0_r3_ROR_29),
    kInstruction_sbc_al_r0_r0_r3_ROR_29,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r12_r7_LSL_24),
    kInstruction_sbc_al_r9_r12_r7_LSL_24,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r5_r4_LSL_10),
    kInstruction_sbc_al_r8_r5_r4_LSL_10,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r2_r12_ROR_10),
    kInstruction_sbc_al_r0_r2_r12_ROR_10,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r0_r5_ROR_16),
    kInstruction_sbc_al_r6_r0_r5_ROR_16,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r9_r14_ROR_2),
    kInstruction_sbc_al_r9_r9_r14_ROR_2,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r0_r7_ROR_28),
    kInstruction_sbc_al_r0_r0_r7_ROR_28,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r11_r12_LSL_16),
    kInstruction_sbc_al_r2_r11_r12_LSL_16,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r0_r8_ROR_13),
    kInstruction_sbc_al_r14_r0_r8_ROR_13,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r4_r3_LSL_2),
    kInstruction_sbc_al_r3_r4_r3_LSL_2,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r6_r4_ROR_25),
    kInstruction_sbc_al_r11_r6_r4_ROR_25,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r1_r12_LSL_4),
    kInstruction_sbc_al_r14_r1_r12_LSL_4,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r2_r6_LSL_12),
    kInstruction_sbc_al_r9_r2_r6_LSL_12,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r9_r2_ROR_26),
    kInstruction_sbc_al_r10_r9_r2_ROR_26,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r3_r10_ROR_2),
    kInstruction_sbc_al_r2_r3_r10_ROR_2,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r7_r9_LSL_12),
    kInstruction_sbc_al_r6_r7_r9_LSL_12,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r1_r7_LSL_6),
    kInstruction_sbc_al_r4_r1_r7_LSL_6,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r3_r13_ROR_31),
    kInstruction_sbc_al_r4_r3_r13_ROR_31,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r1_r0_ROR_11),
    kInstruction_sbc_al_r14_r1_r0_ROR_11,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r3_r9_ROR_18),
    kInstruction_sbc_al_r4_r3_r9_ROR_18,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r5_r2_ROR_26),
    kInstruction_sbc_al_r4_r5_r2_ROR_26,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r13_r9_LSL_1),
    kInstruction_sbc_al_r11_r13_r9_LSL_1,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r13_r8_LSL_31),
    kInstruction_sbc_al_r6_r13_r8_LSL_31,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r6_r5_LSL_7),
    kInstruction_sbc_al_r8_r6_r5_LSL_7,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r12_r11_LSL_29),
    kInstruction_sbc_al_r3_r12_r11_LSL_29,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r11_r3_ROR_25),
    kInstruction_sbc_al_r4_r11_r3_ROR_25,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r0_r3_ROR_1),
    kInstruction_sbc_al_r11_r0_r3_ROR_1,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r7_r8_ROR_14),
    kInstruction_sbc_al_r10_r7_r8_ROR_14,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r8_r5_ROR_17),
    kInstruction_sbc_al_r12_r8_r5_ROR_17,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r11_r1_LSL_26),
    kInstruction_sbc_al_r13_r11_r1_LSL_26,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r4_r5_ROR_26),
    kInstruction_sbc_al_r13_r4_r5_ROR_26,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r5_r8_ROR_17),
    kInstruction_sbc_al_r12_r5_r8_ROR_17,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r0_r10_ROR_16),
    kInstruction_sbc_al_r12_r0_r10_ROR_16,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r4_r14_ROR_28),
    kInstruction_sbc_al_r6_r4_r14_ROR_28,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r13_r5_LSL_16),
    kInstruction_sbc_al_r13_r13_r5_LSL_16,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r6_r10_LSL_15),
    kInstruction_sbc_al_r9_r6_r10_LSL_15,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r10_r8_LSL_16),
    kInstruction_sbc_al_r2_r10_r8_LSL_16,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r4_r0_LSL_5),
    kInstruction_sbc_al_r11_r4_r0_LSL_5,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r2_r14_ROR_31),
    kInstruction_sbc_al_r9_r2_r14_ROR_31,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r7_r11_LSL_25),
    kInstruction_sbc_al_r0_r7_r11_LSL_25,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r6_r12_LSL_8),
    kInstruction_sbc_al_r2_r6_r12_LSL_8,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r10_r4_ROR_7),
    kInstruction_sbc_al_r1_r10_r4_ROR_7,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r3_r7_LSL_10),
    kInstruction_sbc_al_r4_r3_r7_LSL_10,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r7_r11_LSL_14),
    kInstruction_sbc_al_r6_r7_r11_LSL_14,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r10_r0_LSL_31),
    kInstruction_sbc_al_r9_r10_r0_LSL_31,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r5_r13_LSL_2),
    kInstruction_sbc_al_r5_r5_r13_LSL_2,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r10_r2_LSL_26),
    kInstruction_sbc_al_r7_r10_r2_LSL_26,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r7_r7_LSL_29),
    kInstruction_sbc_al_r3_r7_r7_LSL_29,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r1_r8_LSL_18),
    kInstruction_sbc_al_r4_r1_r8_LSL_18,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r12_r2_LSL_29),
    kInstruction_sbc_al_r14_r12_r2_LSL_29,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r6_r3_ROR_8),
    kInstruction_sbc_al_r11_r6_r3_ROR_8,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r5_r3_LSL_7),
    kInstruction_sbc_al_r14_r5_r3_LSL_7,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r13_r12_LSL_2),
    kInstruction_sbc_al_r6_r13_r12_LSL_2,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r1_r0_ROR_13),
    kInstruction_sbc_al_r9_r1_r0_ROR_13,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r5_r7_LSL_16),
    kInstruction_sbc_al_r9_r5_r7_LSL_16,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r6_r0_ROR_27),
    kInstruction_sbc_al_r2_r6_r0_ROR_27,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r9_r5_LSL_19),
    kInstruction_sbc_al_r4_r9_r5_LSL_19,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r5_r13_ROR_26),
    kInstruction_sbc_al_r9_r5_r13_ROR_26,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r9_r14_LSL_25),
    kInstruction_sbc_al_r4_r9_r14_LSL_25,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r13_r1_LSL_22),
    kInstruction_sbc_al_r7_r13_r1_LSL_22,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r13_r6_LSL_25),
    kInstruction_sbc_al_r14_r13_r6_LSL_25,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r12_r14_ROR_1),
    kInstruction_sbc_al_r14_r12_r14_ROR_1,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r7_r4_ROR_28),
    kInstruction_sbc_al_r9_r7_r4_ROR_28,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r14_r11_ROR_4),
    kInstruction_sbc_al_r13_r14_r11_ROR_4,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r6_r14_LSL_22),
    kInstruction_sbc_al_r14_r6_r14_LSL_22,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r10_r13_LSL_27),
    kInstruction_sbc_al_r9_r10_r13_LSL_27,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r1_r7_LSL_17),
    kInstruction_sbc_al_r12_r1_r7_LSL_17,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r0_r5_ROR_6),
    kInstruction_sbc_al_r8_r0_r5_ROR_6,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r11_r6_LSL_6),
    kInstruction_sbc_al_r3_r11_r6_LSL_6,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r5_r7_LSL_23),
    kInstruction_sbc_al_r13_r5_r7_LSL_23,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r8_r1_ROR_20),
    kInstruction_sbc_al_r13_r8_r1_ROR_20,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r0_r7_LSL_10),
    kInstruction_sbc_al_r13_r0_r7_LSL_10,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r1_r12_ROR_17),
    kInstruction_sbc_al_r7_r1_r12_ROR_17,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r3_r12_LSL_12),
    kInstruction_sbc_al_r5_r3_r12_LSL_12,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r12_r4_LSL_6),
    kInstruction_sbc_al_r0_r12_r4_LSL_6,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r11_r11_ROR_8),
    kInstruction_sbc_al_r7_r11_r11_ROR_8,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r0_r0_LSL_17),
    kInstruction_sbc_al_r3_r0_r0_LSL_17,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r12_r0_ROR_2),
    kInstruction_sbc_al_r4_r12_r0_ROR_2,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r3_r3_LSL_25),
    kInstruction_sbc_al_r6_r3_r3_LSL_25,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r5_r5_LSL_9),
    kInstruction_sbc_al_r9_r5_r5_LSL_9,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r3_r4_LSL_20),
    kInstruction_sbc_al_r7_r3_r4_LSL_20,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r1_r7_ROR_6),
    kInstruction_sbc_al_r12_r1_r7_ROR_6,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r14_r7_LSL_23),
    kInstruction_sbc_al_r2_r14_r7_LSL_23,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r6_r9_ROR_22),
    kInstruction_sbc_al_r9_r6_r9_ROR_22,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r8_r2_ROR_11),
    kInstruction_sbc_al_r1_r8_r2_ROR_11,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r2_r14_ROR_15),
    kInstruction_sbc_al_r10_r2_r14_ROR_15,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r1_r9_ROR_27),
    kInstruction_sbc_al_r9_r1_r9_ROR_27,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r11_r13_ROR_30),
    kInstruction_sbc_al_r12_r11_r13_ROR_30,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r11_r1_ROR_5),
    kInstruction_sbc_al_r13_r11_r1_ROR_5,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r8_r10_LSL_24),
    kInstruction_sbc_al_r12_r8_r10_LSL_24,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r6_r10_ROR_19),
    kInstruction_sbc_al_r8_r6_r10_ROR_19,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r0_r2_ROR_26),
    kInstruction_sbc_al_r0_r0_r2_ROR_26,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r14_r10_LSL_28),
    kInstruction_sbc_al_r7_r14_r10_LSL_28,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r2_r12_LSL_12),
    kInstruction_sbc_al_r3_r2_r12_LSL_12,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r3_r8_ROR_29),
    kInstruction_sbc_al_r9_r3_r8_ROR_29,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r11_r12_LSL_14),
    kInstruction_sbc_al_r4_r11_r12_LSL_14,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r5_r11_ROR_9),
    kInstruction_sbc_al_r7_r5_r11_ROR_9,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r7_r7_ROR_2),
    kInstruction_sbc_al_r12_r7_r7_ROR_2,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r6_r9_ROR_24),
    kInstruction_sbc_al_r3_r6_r9_ROR_24,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r14_r9_ROR_12),
    kInstruction_sbc_al_r13_r14_r9_ROR_12,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r3_r13_ROR_2),
    kInstruction_sbc_al_r7_r3_r13_ROR_2,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r11_r3_LSL_21),
    kInstruction_sbc_al_r5_r11_r3_LSL_21,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r9_r9_ROR_17),
    kInstruction_sbc_al_r12_r9_r9_ROR_17,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r12_r13_ROR_3),
    kInstruction_sbc_al_r0_r12_r13_ROR_3,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r4_r7_ROR_28),
    kInstruction_sbc_al_r2_r4_r7_ROR_28,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r14_r8_LSL_5),
    kInstruction_sbc_al_r11_r14_r8_LSL_5,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r3_r14_ROR_11),
    kInstruction_sbc_al_r14_r3_r14_ROR_11,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r4_r9_LSL_10),
    kInstruction_sbc_al_r3_r4_r9_LSL_10,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r5_r3_ROR_11),
    kInstruction_sbc_al_r10_r5_r3_ROR_11,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r12_r2_ROR_29),
    kInstruction_sbc_al_r5_r12_r2_ROR_29,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r10_r8_ROR_29),
    kInstruction_sbc_al_r12_r10_r8_ROR_29,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r2_r12_ROR_13),
    kInstruction_sbc_al_r4_r2_r12_ROR_13,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r7_r7_ROR_29),
    kInstruction_sbc_al_r11_r7_r7_ROR_29,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r10_r2_ROR_20),
    kInstruction_sbc_al_r12_r10_r2_ROR_20,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r11_r3_LSL_6),
    kInstruction_sbc_al_r0_r11_r3_LSL_6,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r8_r10_ROR_13),
    kInstruction_sbc_al_r12_r8_r10_ROR_13,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r3_r9_LSL_30),
    kInstruction_sbc_al_r2_r3_r9_LSL_30,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r5_r8_ROR_27),
    kInstruction_sbc_al_r9_r5_r8_ROR_27,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r3_r12_ROR_16),
    kInstruction_sbc_al_r7_r3_r12_ROR_16,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r8_r3_LSL_29),
    kInstruction_sbc_al_r11_r8_r3_LSL_29,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r9_r3_LSL_13),
    kInstruction_sbc_al_r3_r9_r3_LSL_13,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r2_r13_LSL_7),
    kInstruction_sbc_al_r10_r2_r13_LSL_7,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r0_r9_LSL_22),
    kInstruction_sbc_al_r1_r0_r9_LSL_22,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r3_r9_ROR_24),
    kInstruction_sbc_al_r8_r3_r9_ROR_24,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r13_r8_LSL_25),
    kInstruction_sbc_al_r9_r13_r8_LSL_25,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r2_r13_ROR_16),
    kInstruction_sbc_al_r7_r2_r13_ROR_16,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r6_r3_LSL_3),
    kInstruction_sbc_al_r5_r6_r3_LSL_3,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r6_r10_LSL_15),
    kInstruction_sbc_al_r5_r6_r10_LSL_15,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r8_r12_LSL_13),
    kInstruction_sbc_al_r6_r8_r12_LSL_13,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r9_r11_ROR_7),
    kInstruction_sbc_al_r1_r9_r11_ROR_7,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r3_r7_LSL_12),
    kInstruction_sbc_al_r0_r3_r7_LSL_12,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r10_r2_ROR_6),
    kInstruction_sbc_al_r8_r10_r2_ROR_6,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r11_r5_LSL_10),
    kInstruction_sbc_al_r2_r11_r5_LSL_10,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r5_r4_LSL_15),
    kInstruction_sbc_al_r13_r5_r4_LSL_15,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r1_r12_LSL_27),
    kInstruction_sbc_al_r6_r1_r12_LSL_27,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r3_r5_ROR_19),
    kInstruction_sbc_al_r14_r3_r5_ROR_19,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r0_r13_LSL_12),
    kInstruction_sbc_al_r14_r0_r13_LSL_12,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r2_r8_ROR_15),
    kInstruction_sbc_al_r11_r2_r8_ROR_15,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r1_r3_ROR_1),
    kInstruction_sbc_al_r0_r1_r3_ROR_1,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r11_r11_ROR_31),
    kInstruction_sbc_al_r13_r11_r11_ROR_31,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r4_r4_LSL_20),
    kInstruction_sbc_al_r1_r4_r4_LSL_20,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r7_r6_ROR_7),
    kInstruction_sbc_al_r2_r7_r6_ROR_7,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r3_r11_ROR_21),
    kInstruction_sbc_al_r0_r3_r11_ROR_21,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r9_r6_LSL_20),
    kInstruction_sbc_al_r14_r9_r6_LSL_20,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r2_r14_ROR_1),
    kInstruction_sbc_al_r11_r2_r14_ROR_1,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r10_r8_ROR_22),
    kInstruction_sbc_al_r13_r10_r8_ROR_22,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r2_r2_LSL_27),
    kInstruction_sbc_al_r11_r2_r2_LSL_27,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r2_r14_LSL_6),
    kInstruction_sbc_al_r3_r2_r14_LSL_6,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r3_r0_LSL_20),
    kInstruction_sbc_al_r8_r3_r0_LSL_20,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r14_r11_ROR_19),
    kInstruction_sbc_al_r8_r14_r11_ROR_19,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r14_r0_ROR_8),
    kInstruction_sbc_al_r7_r14_r0_ROR_8,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r6_r3_ROR_13),
    kInstruction_sbc_al_r6_r6_r3_ROR_13,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r9_r3_LSL_10),
    kInstruction_sbc_al_r1_r9_r3_LSL_10,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r12_r14_ROR_13),
    kInstruction_sbc_al_r14_r12_r14_ROR_13,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r5_r13_LSL_19),
    kInstruction_sbc_al_r8_r5_r13_LSL_19,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r10_r10_ROR_3),
    kInstruction_sbc_al_r6_r10_r10_ROR_3,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r5_r1_ROR_19),
    kInstruction_sbc_al_r9_r5_r1_ROR_19,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r8_r1_LSL_12),
    kInstruction_sbc_al_r10_r8_r1_LSL_12,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r0_r6_ROR_31),
    kInstruction_sbc_al_r3_r0_r6_ROR_31,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r6_r5_ROR_1),
    kInstruction_sbc_al_r6_r6_r5_ROR_1,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r0_r0_LSL_18),
    kInstruction_sbc_al_r3_r0_r0_LSL_18,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r12_r1_LSL_11),
    kInstruction_sbc_al_r14_r12_r1_LSL_11,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r13_r1_ROR_17),
    kInstruction_sbc_al_r4_r13_r1_ROR_17,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r13_r0_ROR_10),
    kInstruction_sbc_al_r1_r13_r0_ROR_10,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r0_r0_LSL_11),
    kInstruction_sbc_al_r8_r0_r0_LSL_11,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r3_r10_ROR_18),
    kInstruction_sbc_al_r3_r3_r10_ROR_18,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r8_r9_LSL_7),
    kInstruction_sbc_al_r12_r8_r9_LSL_7,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r3_r11_ROR_10),
    kInstruction_sbc_al_r3_r3_r11_ROR_10,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r14_r6_ROR_5),
    kInstruction_sbc_al_r3_r14_r6_ROR_5,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r0_r12_ROR_7),
    kInstruction_sbc_al_r7_r0_r12_ROR_7,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r2_r8_LSL_13),
    kInstruction_sbc_al_r12_r2_r8_LSL_13,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r1_r0_ROR_8),
    kInstruction_sbc_al_r10_r1_r0_ROR_8,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r12_r6_LSL_30),
    kInstruction_sbc_al_r6_r12_r6_LSL_30,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r3_r7_ROR_11),
    kInstruction_sbc_al_r6_r3_r7_ROR_11,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r12_r7_ROR_28),
    kInstruction_sbc_al_r5_r12_r7_ROR_28,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r12_r10_LSL_6),
    kInstruction_sbc_al_r4_r12_r10_LSL_6,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r5_r1_ROR_3),
    kInstruction_sbc_al_r11_r5_r1_ROR_3,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r3_r0_ROR_26),
    kInstruction_sbc_al_r9_r3_r0_ROR_26,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r1_r10_LSL_13),
    kInstruction_sbc_al_r8_r1_r10_LSL_13,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r13_r14_ROR_20),
    kInstruction_sbc_al_r14_r13_r14_ROR_20,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r3_r8_LSL_7),
    kInstruction_sbc_al_r2_r3_r8_LSL_7,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r11_r10_ROR_4),
    kInstruction_sbc_al_r0_r11_r10_ROR_4,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r6_r9_LSL_27),
    kInstruction_sbc_al_r1_r6_r9_LSL_27,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r2_r4_ROR_10),
    kInstruction_sbc_al_r5_r2_r4_ROR_10,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r8_r9_LSL_20),
    kInstruction_sbc_al_r13_r8_r9_LSL_20,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r7_r0_LSL_20),
    kInstruction_sbc_al_r11_r7_r0_LSL_20,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r9_r1_LSL_30),
    kInstruction_sbc_al_r2_r9_r1_LSL_30,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r0_r5_ROR_24),
    kInstruction_sbc_al_r5_r0_r5_ROR_24,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r4_r10_LSL_17),
    kInstruction_sbc_al_r7_r4_r10_LSL_17,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r3_r7_ROR_19),
    kInstruction_sbc_al_r11_r3_r7_ROR_19,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r2_r6_ROR_1),
    kInstruction_sbc_al_r8_r2_r6_ROR_1,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r1_r8_ROR_25),
    kInstruction_sbc_al_r5_r1_r8_ROR_25,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r4_r12_LSL_28),
    kInstruction_sbc_al_r1_r4_r12_LSL_28,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r1_r4_LSL_14),
    kInstruction_sbc_al_r12_r1_r4_LSL_14,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r12_r13_LSL_25),
    kInstruction_sbc_al_r9_r12_r13_LSL_25,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r14_r5_ROR_12),
    kInstruction_sbc_al_r11_r14_r5_ROR_12,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r8_r13_LSL_4),
    kInstruction_sbc_al_r3_r8_r13_LSL_4,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r14_r10_ROR_12),
    kInstruction_sbc_al_r9_r14_r10_ROR_12,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r13_r1_ROR_30),
    kInstruction_sbc_al_r0_r13_r1_ROR_30,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r9_r9_ROR_23),
    kInstruction_sbc_al_r11_r9_r9_ROR_23,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r2_r8_ROR_6),
    kInstruction_sbc_al_r5_r2_r8_ROR_6,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r14_r10_ROR_23),
    kInstruction_sbc_al_r8_r14_r10_ROR_23,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r12_r2_LSL_26),
    kInstruction_sbc_al_r14_r12_r2_LSL_26,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r9_r10_LSL_12),
    kInstruction_sbc_al_r2_r9_r10_LSL_12,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r1_r11_LSL_17),
    kInstruction_sbc_al_r3_r1_r11_LSL_17,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r8_r10_LSL_23),
    kInstruction_sbc_al_r3_r8_r10_LSL_23,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r6_r4_ROR_31),
    kInstruction_sbc_al_r3_r6_r4_ROR_31,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r5_r10_LSL_22),
    kInstruction_sbc_al_r3_r5_r10_LSL_22,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r3_r10_ROR_1),
    kInstruction_sbc_al_r0_r3_r10_ROR_1,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r9_r7_ROR_9),
    kInstruction_sbc_al_r5_r9_r7_ROR_9,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r2_r2_LSL_24),
    kInstruction_sbc_al_r11_r2_r2_LSL_24,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r11_r7_LSL_29),
    kInstruction_sbc_al_r10_r11_r7_LSL_29,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r4_r10_ROR_26),
    kInstruction_sbc_al_r5_r4_r10_ROR_26,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r8_r7_LSL_20),
    kInstruction_sbc_al_r8_r8_r7_LSL_20,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r6_r5_ROR_20),
    kInstruction_sbc_al_r12_r6_r5_ROR_20,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r4_r7_LSL_21),
    kInstruction_sbc_al_r9_r4_r7_LSL_21,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r2_r7_LSL_4),
    kInstruction_sbc_al_r8_r2_r7_LSL_4,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r14_r12_LSL_8),
    kInstruction_sbc_al_r9_r14_r12_LSL_8,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r12_r8_ROR_25),
    kInstruction_sbc_al_r1_r12_r8_ROR_25,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r1_r4_ROR_26),
    kInstruction_sbc_al_r4_r1_r4_ROR_26,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r6_r14_ROR_22),
    kInstruction_sbc_al_r12_r6_r14_ROR_22,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r6_r9_LSL_17),
    kInstruction_sbc_al_r2_r6_r9_LSL_17,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r8_r1_ROR_15),
    kInstruction_sbc_al_r8_r8_r1_ROR_15,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r10_r8_ROR_27),
    kInstruction_sbc_al_r13_r10_r8_ROR_27,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r10_r10_LSL_27),
    kInstruction_sbc_al_r1_r10_r10_LSL_27,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r1_r11_ROR_26),
    kInstruction_sbc_al_r7_r1_r11_ROR_26,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r14_r11_ROR_29),
    kInstruction_sbc_al_r13_r14_r11_ROR_29,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r3_r14_ROR_7),
    kInstruction_sbc_al_r5_r3_r14_ROR_7,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r12_r9_LSL_22),
    kInstruction_sbc_al_r2_r12_r9_LSL_22,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r2_r9_LSL_12),
    kInstruction_sbc_al_r4_r2_r9_LSL_12,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r7_r5_LSL_8),
    kInstruction_sbc_al_r6_r7_r5_LSL_8,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r11_r6_LSL_10),
    kInstruction_sbc_al_r14_r11_r6_LSL_10,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r10_r7_ROR_10),
    kInstruction_sbc_al_r11_r10_r7_ROR_10,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r11_r5_ROR_8),
    kInstruction_sbc_al_r9_r11_r5_ROR_8,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r12_r0_ROR_1),
    kInstruction_sbc_al_r13_r12_r0_ROR_1,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r9_r3_ROR_1),
    kInstruction_sbc_al_r7_r9_r3_ROR_1,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r2_r13_LSL_17),
    kInstruction_sbc_al_r10_r2_r13_LSL_17,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r6_r6_LSL_16),
    kInstruction_sbc_al_r10_r6_r6_LSL_16,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r8_r9_ROR_25),
    kInstruction_sbc_al_r5_r8_r9_ROR_25,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r13_r2_LSL_23),
    kInstruction_sbc_al_r14_r13_r2_LSL_23,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r13_r6_ROR_13),
    kInstruction_sbc_al_r5_r13_r6_ROR_13,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r14_r5_LSL_3),
    kInstruction_sbc_al_r6_r14_r5_LSL_3,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r8_r14_ROR_2),
    kInstruction_sbc_al_r11_r8_r14_ROR_2,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r11_r13_ROR_25),
    kInstruction_sbc_al_r3_r11_r13_ROR_25,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r1_r6_LSL_3),
    kInstruction_sbc_al_r2_r1_r6_LSL_3,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r7_r3_ROR_30),
    kInstruction_sbc_al_r1_r7_r3_ROR_30,
  },
};

#endif  // VIXL_ASSEMBLER_COND_RD_RN_OPERAND_RM_SHIFT_AMOUNT_1TO31_SBC_T32_H_
